@charset "UTF-8";
/* basic scrollbar styling */
/* vertical scrollbar */
.mCSB_container {
  width: auto;
  margin-right: 30px;
  overflow: hidden; }

.mCSB_container.mCS_no_scrollbar {
  margin-right: 0; }

.mCS_disabled .mCSB_container.mCS_no_scrollbar, .mCS_destroyed .mCSB_container.mCS_no_scrollbar {
  margin-right: 30px; }

.mCustomScrollBox .mCSB_scrollTools {
  width: 16px;
  height: 100%;
  top: 0;
  right: 0; }

.mCSB_scrollTools .mCSB_draggerContainer {
  height: 100%;
  box-sizing: border-box; }

.mCSB_scrollTools .mCSB_buttonUp + .mCSB_draggerContainer {
  padding-bottom: 40px; }

.mCSB_scrollTools .mCSB_draggerRail {
  width: 2px;
  height: 100%;
  margin: 0 auto;
  border-radius: 10px; }

.mCSB_scrollTools .mCSB_dragger {
  cursor: pointer;
  width: 100%;
  height: 30px; }

.mCSB_scrollTools .mCSB_dragger .mCSB_dragger_bar {
  width: 4px;
  height: 100%;
  margin: 0 auto;
  border-radius: 10px;
  text-align: center; }

.mCSB_scrollTools .mCSB_buttonUp, .mCSB_scrollTools .mCSB_buttonDown {
  height: 20px;
  overflow: hidden;
  margin: 0 auto;
  cursor: pointer; }

.mCSB_scrollTools .mCSB_buttonDown {
  bottom: 0;
  margin-top: -40px; }

/* horizontal scrollbar */
.mCSB_horizontal .mCSB_container {
  height: auto;
  margin-right: 0;
  margin-bottom: 30px;
  overflow: hidden; }

.mCSB_horizontal .mCSB_container.mCS_no_scrollbar {
  margin-bottom: 0; }

.mCS_disabled .mCSB_horizontal .mCSB_container.mCS_no_scrollbar, .mCS_destroyed .mCSB_horizontal .mCSB_container.mCS_no_scrollbar {
  margin-right: 0;
  margin-bottom: 30px; }

.mCSB_horizontal.mCustomScrollBox .mCSB_scrollTools {
  width: 100%;
  height: 16px;
  top: auto;
  right: auto;
  bottom: 0;
  left: 0;
  overflow: hidden; }

.mCSB_horizontal .mCSB_scrollTools .mCSB_draggerContainer {
  height: 100%;
  width: auto;
  box-sizing: border-box;
  overflow: hidden; }

.mCSB_horizontal .mCSB_scrollTools .mCSB_buttonLeft + .mCSB_draggerContainer {
  padding-bottom: 0;
  padding-right: 20px; }

.mCSB_horizontal .mCSB_scrollTools .mCSB_draggerRail {
  width: 100%;
  height: 2px;
  margin: 7px 0;
  border-radius: 10px; }

.mCSB_horizontal .mCSB_scrollTools .mCSB_dragger {
  width: 30px;
  height: 100%; }

.mCSB_horizontal .mCSB_scrollTools .mCSB_dragger .mCSB_dragger_bar {
  width: 100%;
  height: 4px;
  margin: 6px auto;
  border-radius: 10px; }

.mCSB_horizontal .mCSB_scrollTools .mCSB_buttonLeft, .mCSB_horizontal .mCSB_scrollTools .mCSB_buttonRight {
  width: 20px;
  height: 100%;
  overflow: hidden;
  margin: 0 auto;
  cursor: pointer;
  float: left; }

.mCSB_horizontal .mCSB_scrollTools .mCSB_buttonRight {
  right: 0;
  bottom: auto;
  margin-left: -40px;
  margin-top: -16px;
  float: right; }

/* default scrollbar colors and backgrounds */
.mCustomScrollBox .mCSB_scrollTools {
  opacity: 0.75; }

.mCustomScrollBox:hover .mCSB_scrollTools {
  opacity: 1; }

.mCSB_scrollTools .mCSB_draggerRail {
  background: #000;
  /* rgba fallback */
  background: rgba(0, 0, 0, 0.4);
  filter: "alpha(opacity=40)";
  -ms-filter: "alpha(opacity=40)";
  /* old ie */ }

.mCSB_scrollTools .mCSB_dragger .mCSB_dragger_bar {
  background: #fff;
  /* rgba fallback */
  background: rgba(255, 255, 255, 0.75);
  filter: "alpha(opacity=75)";
  -ms-filter: "alpha(opacity=75)";
  /* old ie */ }

.mCSB_scrollTools .mCSB_dragger:hover .mCSB_dragger_bar {
  background: rgba(255, 255, 255, 0.85);
  filter: "alpha(opacity=85)";
  -ms-filter: "alpha(opacity=85)";
  /* old ie */ }

.mCSB_scrollTools .mCSB_dragger:active .mCSB_dragger_bar, .mCSB_scrollTools .mCSB_dragger.mCSB_dragger_onDrag .mCSB_dragger_bar {
  background: rgba(255, 255, 255, 0.9);
  filter: "alpha(opacity=90)";
  -ms-filter: "alpha(opacity=90)";
  /* old ie */ }

.mCSB_scrollTools .mCSB_buttonUp, .mCSB_scrollTools .mCSB_buttonDown, .mCSB_scrollTools .mCSB_buttonLeft, .mCSB_scrollTools .mCSB_buttonRight {
  background-image: url(mCSB_buttons.png);
  background-repeat: no-repeat;
  opacity: 0.4;
  filter: "alpha(opacity=40)";
  -ms-filter: "alpha(opacity=40)";
  /* old ie */ }

.mCSB_scrollTools .mCSB_buttonUp {
  background-position: 0 0;
  /* 
	sprites locations are 0 0/-16px 0/-32px 0/-48px 0 (light) and -80px 0/-96px 0/-112px 0/-128px 0 (dark) 
	*/ }

.mCSB_scrollTools .mCSB_buttonDown {
  background-position: 0 -20px;
  /* 
	sprites locations are 0 -20px/-16px -20px/-32px -20px/-48px -20px (light) and -80px -20px/-96px -20px/-112px -20px/-128px -20px (dark) 
	*/ }

.mCSB_scrollTools .mCSB_buttonLeft {
  background-position: 0 -40px;
  /* 
	sprites locations are 0 -40px/-20px -40px/-40px -40px/-60px -40px (light) and -80px -40px/-100px -40px/-120px -40px/-140px -40px (dark) 
	*/ }

.mCSB_scrollTools .mCSB_buttonRight {
  background-position: 0 -56px;
  /* 
	sprites locations are 0 -56px/-20px -56px/-40px -56px/-60px -56px (light) and -80px -56px/-100px -56px/-120px -56px/-140px -56px (dark) 
	*/ }

.mCSB_scrollTools .mCSB_buttonUp:hover, .mCSB_scrollTools .mCSB_buttonDown:hover, .mCSB_scrollTools .mCSB_buttonLeft:hover, .mCSB_scrollTools .mCSB_buttonRight:hover {
  opacity: 0.75;
  filter: "alpha(opacity=75)";
  -ms-filter: "alpha(opacity=75)";
  /* old ie */ }

.mCSB_scrollTools .mCSB_buttonUp:active, .mCSB_scrollTools .mCSB_buttonDown:active, .mCSB_scrollTools .mCSB_buttonLeft:active, .mCSB_scrollTools .mCSB_buttonRight:active {
  opacity: 0.9;
  filter: "alpha(opacity=90)";
  -ms-filter: "alpha(opacity=90)";
  /* old ie */ }

/* Magnific Popup CSS */
.mfp-bg {
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 1042;
  overflow: hidden;
  position: fixed;
  background: #0b0b0b;
  opacity: 0.8;
  filter: alpha(opacity=80); }

.mfp-wrap {
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 1043;
  position: fixed;
  outline: none !important;
  -webkit-backface-visibility: hidden; }

.mfp-container {
  text-align: center;
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  padding: 0 8px;
  box-sizing: border-box; }

.mfp-container:before {
  content: '';
  display: inline-block;
  height: 100%;
  vertical-align: middle; }

.mfp-align-top .mfp-container:before {
  display: none; }

.mfp-content {
  position: relative;
  display: inline-block;
  vertical-align: middle;
  margin: 0 auto;
  text-align: left;
  z-index: 1045; }

.mfp-inline-holder .mfp-content,
.mfp-ajax-holder .mfp-content {
  width: 100%;
  cursor: auto; }

.mfp-ajax-cur {
  cursor: progress; }

.mfp-zoom-out-cur, .mfp-zoom-out-cur .mfp-image-holder .mfp-close {
  cursor: -webkit-zoom-out;
  cursor: zoom-out; }

.mfp-zoom {
  cursor: pointer;
  cursor: -webkit-zoom-in;
  cursor: zoom-in; }

.mfp-auto-cursor .mfp-content {
  cursor: auto; }

.mfp-close,
.mfp-arrow,
.mfp-preloader,
.mfp-counter {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
      user-select: none; }

.mfp-loading.mfp-figure {
  display: none; }

.mfp-hide {
  display: none !important; }

.mfp-preloader {
  color: #CCC;
  position: absolute;
  top: 50%;
  width: auto;
  text-align: center;
  margin-top: -0.8em;
  left: 8px;
  right: 8px;
  z-index: 1044; }
  .mfp-preloader a {
    color: #CCC; }
    .mfp-preloader a:hover {
      color: #FFF; }

.mfp-s-ready .mfp-preloader {
  display: none; }

.mfp-s-error .mfp-content {
  display: none; }

button.mfp-close, button.mfp-arrow {
  overflow: visible;
  cursor: pointer;
  background: transparent;
  border: 0;
  -webkit-appearance: none;
  display: block;
  outline: none;
  padding: 0;
  z-index: 1046;
  box-shadow: none; }

button::-moz-focus-inner {
  padding: 0;
  border: 0; }

.mfp-close {
  width: 44px;
  height: 44px;
  line-height: 44px;
  position: absolute;
  right: 0;
  top: 0;
  text-decoration: none;
  text-align: center;
  opacity: 0.65;
  filter: alpha(opacity=65);
  padding: 0 0 18px 10px;
  color: #FFF;
  font-style: normal;
  font-size: 28px;
  font-family: Arial, Baskerville, monospace; }
  .mfp-close:hover, .mfp-close:focus {
    opacity: 1;
    filter: alpha(opacity=100); }
  .mfp-close:active {
    top: 1px; }

.mfp-close-btn-in .mfp-close {
  color: #333; }

.mfp-image-holder .mfp-close,
.mfp-iframe-holder .mfp-close {
  color: #FFF;
  right: -6px;
  text-align: right;
  padding-right: 6px;
  width: 100%; }

.mfp-counter {
  position: absolute;
  top: 0;
  right: 0;
  color: #CCC;
  font-size: 12px;
  line-height: 18px;
  white-space: nowrap; }

.mfp-arrow {
  position: absolute;
  opacity: 0.65;
  filter: alpha(opacity=65);
  margin: 0;
  top: 50%;
  margin-top: -55px;
  padding: 0;
  width: 90px;
  height: 110px;
  -webkit-tap-highlight-color: transparent; }
  .mfp-arrow:active {
    margin-top: -54px; }
  .mfp-arrow:hover, .mfp-arrow:focus {
    opacity: 1;
    filter: alpha(opacity=100); }
  .mfp-arrow:before, .mfp-arrow:after,
  .mfp-arrow .mfp-b,
  .mfp-arrow .mfp-a {
    content: '';
    display: block;
    width: 0;
    height: 0;
    position: absolute;
    left: 0;
    top: 0;
    margin-top: 35px;
    margin-left: 35px;
    border: medium inset transparent; }
  .mfp-arrow:after,
  .mfp-arrow .mfp-a {
    border-top-width: 13px;
    border-bottom-width: 13px;
    top: 8px; }
  .mfp-arrow:before,
  .mfp-arrow .mfp-b {
    border-top-width: 21px;
    border-bottom-width: 21px;
    opacity: 0.7; }

.mfp-arrow-left {
  left: 0; }
  .mfp-arrow-left:after,
  .mfp-arrow-left .mfp-a {
    border-right: 17px solid #FFF;
    margin-left: 31px; }
  .mfp-arrow-left:before,
  .mfp-arrow-left .mfp-b {
    margin-left: 25px;
    border-right: 27px solid #3F3F3F; }

.mfp-arrow-right {
  right: 0; }
  .mfp-arrow-right:after,
  .mfp-arrow-right .mfp-a {
    border-left: 17px solid #FFF;
    margin-left: 39px; }
  .mfp-arrow-right:before,
  .mfp-arrow-right .mfp-b {
    border-left: 27px solid #3F3F3F; }

.mfp-iframe-holder {
  padding-top: 40px;
  padding-bottom: 40px; }
  .mfp-iframe-holder .mfp-content {
    line-height: 0;
    width: 100%;
    max-width: 900px; }
  .mfp-iframe-holder .mfp-close {
    top: -40px; }

.mfp-iframe-scaler {
  width: 100%;
  height: 0;
  overflow: hidden;
  padding-top: 56.25%; }
  .mfp-iframe-scaler iframe {
    position: absolute;
    display: block;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
    background: #000; }

/* Main image in popup */
img.mfp-img {
  width: auto;
  max-width: 100%;
  height: auto;
  display: block;
  line-height: 0;
  box-sizing: border-box;
  padding: 40px 0 40px;
  margin: 0 auto; }

/* The shadow behind the image */
.mfp-figure {
  line-height: 0; }
  .mfp-figure:after {
    content: '';
    position: absolute;
    left: 0;
    top: 40px;
    bottom: 40px;
    display: block;
    right: 0;
    width: auto;
    height: auto;
    z-index: -1;
    box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
    background: #444; }
  .mfp-figure small {
    color: #BDBDBD;
    display: block;
    font-size: 12px;
    line-height: 14px; }
  .mfp-figure figure {
    margin: 0; }

.mfp-bottom-bar {
  margin-top: -36px;
  position: absolute;
  top: 100%;
  left: 0;
  width: 100%;
  cursor: auto; }

.mfp-title {
  text-align: left;
  line-height: 18px;
  color: #F3F3F3;
  word-wrap: break-word;
  padding-right: 36px; }

.mfp-image-holder .mfp-content {
  max-width: 100%; }

.mfp-gallery .mfp-image-holder .mfp-figure {
  cursor: pointer; }

@media screen and (max-width: 800px) and (orientation: landscape), screen and (max-height: 300px) {
  /**
       * Remove all paddings around the image on small screen
       */
  .mfp-img-mobile .mfp-image-holder {
    padding-left: 0;
    padding-right: 0; }
  .mfp-img-mobile img.mfp-img {
    padding: 0; }
  .mfp-img-mobile .mfp-figure:after {
    top: 0;
    bottom: 0; }
  .mfp-img-mobile .mfp-figure small {
    display: inline;
    margin-left: 5px; }
  .mfp-img-mobile .mfp-bottom-bar {
    background: rgba(0, 0, 0, 0.6);
    bottom: 0;
    margin: 0;
    top: auto;
    padding: 3px 5px;
    position: fixed;
    box-sizing: border-box; }
    .mfp-img-mobile .mfp-bottom-bar:empty {
      padding: 0; }
  .mfp-img-mobile .mfp-counter {
    right: 5px;
    top: 3px; }
  .mfp-img-mobile .mfp-close {
    top: 0;
    right: 0;
    width: 35px;
    height: 35px;
    line-height: 35px;
    background: rgba(0, 0, 0, 0.6);
    position: fixed;
    text-align: center;
    padding: 0; } }

@media all and (max-width: 900px) {
  .mfp-arrow {
    -webkit-transform: scale(0.75);
    -ms-transform: scale(0.75);
        transform: scale(0.75); }
  .mfp-arrow-left {
    -webkit-transform-origin: 0;
    -ms-transform-origin: 0;
        transform-origin: 0; }
  .mfp-arrow-right {
    -webkit-transform-origin: 100%;
    -ms-transform-origin: 100%;
        transform-origin: 100%; }
  .mfp-container {
    padding-left: 6px;
    padding-right: 6px; } }

.mfp-ie7 .mfp-img {
  padding: 0; }

.mfp-ie7 .mfp-bottom-bar {
  width: 600px;
  left: 50%;
  margin-left: -300px;
  margin-top: 5px;
  padding-bottom: 5px; }

.mfp-ie7 .mfp-container {
  padding: 0; }

.mfp-ie7 .mfp-content {
  padding-top: 44px; }

.mfp-ie7 .mfp-close {
  top: 0;
  right: 0;
  padding-top: 0; }

.emojione {
  /* Emoji Sizing */
  font-size: inherit;
  height: 3ex;
  width: 3.1ex;
  min-height: 20px;
  min-width: 20px;
  /* Inline alignment adjust the margins  */
  display: inline-block;
  margin: -.2ex .15em .2ex;
  line-height: normal;
  vertical-align: middle; }

img.emojione {
  /* prevent img stretch */
  width: auto; }

/* BEGIN: bootstrap */
@keyframes progress-bar-stripes {
  from {
    background-position: 40px 0; }
  to {
    background-position: 0 0; } }

@-webkit-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0; }
  to {
    background-position: 0 0; } }

@keyframes progress-bar-stripes {
  from {
    background-position: 40px 0; }
  to {
    background-position: 0 0; } }

#jsxc_dialog .progress {
  overflow: hidden;
  height: 20px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border-radius: 4px;
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1); }

#jsxc_dialog .progress-bar {
  float: left;
  width: 0%;
  height: 100%;
  font-size: 12px;
  line-height: 20px;
  color: #fff;
  text-align: center;
  background-color: #337ab7;
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  -webkit-transition: width 0.6s ease;
  transition: width 0.6s ease; }

#jsxc_dialog .progress-striped .progress-bar,
#jsxc_dialog .progress-bar-striped {
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-size: 40px 40px; }

#jsxc_dialog .progress.active .progress-bar,
#jsxc_dialog .progress-bar.active {
  -webkit-animation: progress-bar-stripes 2s linear infinite;
  animation: progress-bar-stripes 2s linear infinite; }

#jsxc_dialog .progress-bar-success {
  background-color: #5cb85c; }
  .progress-striped #jsxc_dialog .progress-bar-success {
    background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

#jsxc_dialog .progress-bar-info {
  background-color: #5bc0de; }
  .progress-striped #jsxc_dialog .progress-bar-info {
    background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

#jsxc_dialog .progress-bar-warning {
  background-color: #f0ad4e; }
  .progress-striped #jsxc_dialog .progress-bar-warning {
    background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

#jsxc_dialog .progress-bar-danger {
  background-color: #d9534f; }
  .progress-striped #jsxc_dialog .progress-bar-danger {
    background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
    background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

#jsxc_dialog .clearfix:before, #jsxc_dialog .clearfix:after, #jsxc_webrtc .clearfix:before, #jsxc_webrtc .clearfix:after {
  content: " ";
  display: table; }

#jsxc_dialog .clearfix:after, #jsxc_webrtc .clearfix:after {
  clear: both; }

#jsxc_dialog .center-block, #jsxc_webrtc .center-block {
  display: block;
  margin-left: auto;
  margin-right: auto; }

#jsxc_dialog .pull-right, #jsxc_webrtc .pull-right {
  float: right !important; }

#jsxc_dialog .pull-left, #jsxc_webrtc .pull-left {
  float: left !important; }

#jsxc_dialog .hide, #jsxc_webrtc .hide {
  display: none !important; }

#jsxc_dialog .show, #jsxc_webrtc .show {
  display: block !important; }

#jsxc_dialog .invisible, #jsxc_webrtc .invisible {
  visibility: hidden; }

#jsxc_dialog .text-hide, #jsxc_webrtc .text-hide {
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0; }

#jsxc_dialog .hidden, #jsxc_webrtc .hidden {
  display: none !important; }

#jsxc_dialog .affix, #jsxc_webrtc .affix {
  position: fixed; }

#jsxc_dialog code,
#jsxc_dialog kbd,
#jsxc_dialog pre,
#jsxc_dialog samp, #jsxc_webrtc code,
#jsxc_webrtc kbd,
#jsxc_webrtc pre,
#jsxc_webrtc samp {
  font-family: Menlo, Monaco, Consolas, "Courier New", monospace; }

#jsxc_dialog code, #jsxc_webrtc code {
  padding: 2px 4px;
  font-size: 90%;
  color: #c7254e;
  background-color: #f9f2f4;
  border-radius: 4px; }

#jsxc_dialog kbd, #jsxc_webrtc kbd {
  padding: 2px 4px;
  font-size: 90%;
  color: #fff;
  background-color: #333;
  border-radius: 3px;
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25); }
  #jsxc_dialog kbd kbd, #jsxc_webrtc kbd kbd {
    padding: 0;
    font-size: 100%;
    font-weight: bold;
    box-shadow: none; }

#jsxc_dialog pre, #jsxc_webrtc pre {
  display: block;
  padding: 9.5px;
  margin: 0 0 10px;
  font-size: 13px;
  line-height: 1.428571429;
  word-break: break-all;
  word-wrap: break-word;
  color: #333333;
  background-color: #f5f5f5;
  border: 1px solid #ccc;
  border-radius: 4px; }
  #jsxc_dialog pre code, #jsxc_webrtc pre code {
    padding: 0;
    font-size: inherit;
    color: inherit;
    white-space: pre-wrap;
    background-color: transparent;
    border-radius: 0; }

#jsxc_dialog .pre-scrollable, #jsxc_webrtc .pre-scrollable {
  max-height: 340px;
  overflow-y: scroll; }

#jsxc_dialog .container, #jsxc_webrtc .container {
  margin-right: auto;
  margin-left: auto;
  padding-left: 15px;
  padding-right: 15px; }
  #jsxc_dialog .container:before, #jsxc_dialog .container:after, #jsxc_webrtc .container:before, #jsxc_webrtc .container:after {
    content: " ";
    display: table; }
  #jsxc_dialog .container:after, #jsxc_webrtc .container:after {
    clear: both; }
  @media (min-width: 768px) {
    #jsxc_dialog .container, #jsxc_webrtc .container {
      width: 750px; } }
  @media (min-width: 992px) {
    #jsxc_dialog .container, #jsxc_webrtc .container {
      width: 970px; } }
  @media (min-width: 1200px) {
    #jsxc_dialog .container, #jsxc_webrtc .container {
      width: 1170px; } }

#jsxc_dialog .container-fluid, #jsxc_webrtc .container-fluid {
  margin-right: auto;
  margin-left: auto;
  padding-left: 15px;
  padding-right: 15px; }
  #jsxc_dialog .container-fluid:before, #jsxc_dialog .container-fluid:after, #jsxc_webrtc .container-fluid:before, #jsxc_webrtc .container-fluid:after {
    content: " ";
    display: table; }
  #jsxc_dialog .container-fluid:after, #jsxc_webrtc .container-fluid:after {
    clear: both; }

#jsxc_dialog .row, #jsxc_webrtc .row {
  margin-left: -15px;
  margin-right: -15px; }
  #jsxc_dialog .row:before, #jsxc_dialog .row:after, #jsxc_webrtc .row:before, #jsxc_webrtc .row:after {
    content: " ";
    display: table; }
  #jsxc_dialog .row:after, #jsxc_webrtc .row:after {
    clear: both; }

#jsxc_dialog .col-xs-1, #jsxc_dialog .col-sm-1, #jsxc_dialog .col-md-1, #jsxc_dialog .col-lg-1, #jsxc_dialog .col-xs-2, #jsxc_dialog .col-sm-2, #jsxc_dialog .col-md-2, #jsxc_dialog .col-lg-2, #jsxc_dialog .col-xs-3, #jsxc_dialog .col-sm-3, #jsxc_dialog .col-md-3, #jsxc_dialog .col-lg-3, #jsxc_dialog .col-xs-4, #jsxc_dialog .col-sm-4, #jsxc_dialog .col-md-4, #jsxc_dialog .col-lg-4, #jsxc_dialog .col-xs-5, #jsxc_dialog .col-sm-5, #jsxc_dialog .col-md-5, #jsxc_dialog .col-lg-5, #jsxc_dialog .col-xs-6, #jsxc_dialog .col-sm-6, #jsxc_dialog .col-md-6, #jsxc_dialog .col-lg-6, #jsxc_dialog .col-xs-7, #jsxc_dialog .col-sm-7, #jsxc_dialog .col-md-7, #jsxc_dialog .col-lg-7, #jsxc_dialog .col-xs-8, #jsxc_dialog .col-sm-8, #jsxc_dialog .col-md-8, #jsxc_dialog .col-lg-8, #jsxc_dialog .col-xs-9, #jsxc_dialog .col-sm-9, #jsxc_dialog .col-md-9, #jsxc_dialog .col-lg-9, #jsxc_dialog .col-xs-10, #jsxc_dialog .col-sm-10, #jsxc_dialog .col-md-10, #jsxc_dialog .col-lg-10, #jsxc_dialog .col-xs-11, #jsxc_dialog .col-sm-11, #jsxc_dialog .col-md-11, #jsxc_dialog .col-lg-11, #jsxc_dialog .col-xs-12, #jsxc_dialog .col-sm-12, #jsxc_dialog .col-md-12, #jsxc_dialog .col-lg-12, #jsxc_webrtc .col-xs-1, #jsxc_webrtc .col-sm-1, #jsxc_webrtc .col-md-1, #jsxc_webrtc .col-lg-1, #jsxc_webrtc .col-xs-2, #jsxc_webrtc .col-sm-2, #jsxc_webrtc .col-md-2, #jsxc_webrtc .col-lg-2, #jsxc_webrtc .col-xs-3, #jsxc_webrtc .col-sm-3, #jsxc_webrtc .col-md-3, #jsxc_webrtc .col-lg-3, #jsxc_webrtc .col-xs-4, #jsxc_webrtc .col-sm-4, #jsxc_webrtc .col-md-4, #jsxc_webrtc .col-lg-4, #jsxc_webrtc .col-xs-5, #jsxc_webrtc .col-sm-5, #jsxc_webrtc .col-md-5, #jsxc_webrtc .col-lg-5, #jsxc_webrtc .col-xs-6, #jsxc_webrtc .col-sm-6, #jsxc_webrtc .col-md-6, #jsxc_webrtc .col-lg-6, #jsxc_webrtc .col-xs-7, #jsxc_webrtc .col-sm-7, #jsxc_webrtc .col-md-7, #jsxc_webrtc .col-lg-7, #jsxc_webrtc .col-xs-8, #jsxc_webrtc .col-sm-8, #jsxc_webrtc .col-md-8, #jsxc_webrtc .col-lg-8, #jsxc_webrtc .col-xs-9, #jsxc_webrtc .col-sm-9, #jsxc_webrtc .col-md-9, #jsxc_webrtc .col-lg-9, #jsxc_webrtc .col-xs-10, #jsxc_webrtc .col-sm-10, #jsxc_webrtc .col-md-10, #jsxc_webrtc .col-lg-10, #jsxc_webrtc .col-xs-11, #jsxc_webrtc .col-sm-11, #jsxc_webrtc .col-md-11, #jsxc_webrtc .col-lg-11, #jsxc_webrtc .col-xs-12, #jsxc_webrtc .col-sm-12, #jsxc_webrtc .col-md-12, #jsxc_webrtc .col-lg-12 {
  position: relative;
  min-height: 1px;
  padding-left: 15px;
  padding-right: 15px; }

#jsxc_dialog .col-xs-1, #jsxc_dialog .col-xs-2, #jsxc_dialog .col-xs-3, #jsxc_dialog .col-xs-4, #jsxc_dialog .col-xs-5, #jsxc_dialog .col-xs-6, #jsxc_dialog .col-xs-7, #jsxc_dialog .col-xs-8, #jsxc_dialog .col-xs-9, #jsxc_dialog .col-xs-10, #jsxc_dialog .col-xs-11, #jsxc_dialog .col-xs-12, #jsxc_webrtc .col-xs-1, #jsxc_webrtc .col-xs-2, #jsxc_webrtc .col-xs-3, #jsxc_webrtc .col-xs-4, #jsxc_webrtc .col-xs-5, #jsxc_webrtc .col-xs-6, #jsxc_webrtc .col-xs-7, #jsxc_webrtc .col-xs-8, #jsxc_webrtc .col-xs-9, #jsxc_webrtc .col-xs-10, #jsxc_webrtc .col-xs-11, #jsxc_webrtc .col-xs-12 {
  float: left; }

#jsxc_dialog .col-xs-1, #jsxc_webrtc .col-xs-1 {
  width: 8.3333333333%; }

#jsxc_dialog .col-xs-2, #jsxc_webrtc .col-xs-2 {
  width: 16.6666666667%; }

#jsxc_dialog .col-xs-3, #jsxc_webrtc .col-xs-3 {
  width: 25%; }

#jsxc_dialog .col-xs-4, #jsxc_webrtc .col-xs-4 {
  width: 33.3333333333%; }

#jsxc_dialog .col-xs-5, #jsxc_webrtc .col-xs-5 {
  width: 41.6666666667%; }

#jsxc_dialog .col-xs-6, #jsxc_webrtc .col-xs-6 {
  width: 50%; }

#jsxc_dialog .col-xs-7, #jsxc_webrtc .col-xs-7 {
  width: 58.3333333333%; }

#jsxc_dialog .col-xs-8, #jsxc_webrtc .col-xs-8 {
  width: 66.6666666667%; }

#jsxc_dialog .col-xs-9, #jsxc_webrtc .col-xs-9 {
  width: 75%; }

#jsxc_dialog .col-xs-10, #jsxc_webrtc .col-xs-10 {
  width: 83.3333333333%; }

#jsxc_dialog .col-xs-11, #jsxc_webrtc .col-xs-11 {
  width: 91.6666666667%; }

#jsxc_dialog .col-xs-12, #jsxc_webrtc .col-xs-12 {
  width: 100%; }

#jsxc_dialog .col-xs-pull-0, #jsxc_webrtc .col-xs-pull-0 {
  right: auto; }

#jsxc_dialog .col-xs-pull-1, #jsxc_webrtc .col-xs-pull-1 {
  right: 8.3333333333%; }

#jsxc_dialog .col-xs-pull-2, #jsxc_webrtc .col-xs-pull-2 {
  right: 16.6666666667%; }

#jsxc_dialog .col-xs-pull-3, #jsxc_webrtc .col-xs-pull-3 {
  right: 25%; }

#jsxc_dialog .col-xs-pull-4, #jsxc_webrtc .col-xs-pull-4 {
  right: 33.3333333333%; }

#jsxc_dialog .col-xs-pull-5, #jsxc_webrtc .col-xs-pull-5 {
  right: 41.6666666667%; }

#jsxc_dialog .col-xs-pull-6, #jsxc_webrtc .col-xs-pull-6 {
  right: 50%; }

#jsxc_dialog .col-xs-pull-7, #jsxc_webrtc .col-xs-pull-7 {
  right: 58.3333333333%; }

#jsxc_dialog .col-xs-pull-8, #jsxc_webrtc .col-xs-pull-8 {
  right: 66.6666666667%; }

#jsxc_dialog .col-xs-pull-9, #jsxc_webrtc .col-xs-pull-9 {
  right: 75%; }

#jsxc_dialog .col-xs-pull-10, #jsxc_webrtc .col-xs-pull-10 {
  right: 83.3333333333%; }

#jsxc_dialog .col-xs-pull-11, #jsxc_webrtc .col-xs-pull-11 {
  right: 91.6666666667%; }

#jsxc_dialog .col-xs-pull-12, #jsxc_webrtc .col-xs-pull-12 {
  right: 100%; }

#jsxc_dialog .col-xs-push-0, #jsxc_webrtc .col-xs-push-0 {
  left: auto; }

#jsxc_dialog .col-xs-push-1, #jsxc_webrtc .col-xs-push-1 {
  left: 8.3333333333%; }

#jsxc_dialog .col-xs-push-2, #jsxc_webrtc .col-xs-push-2 {
  left: 16.6666666667%; }

#jsxc_dialog .col-xs-push-3, #jsxc_webrtc .col-xs-push-3 {
  left: 25%; }

#jsxc_dialog .col-xs-push-4, #jsxc_webrtc .col-xs-push-4 {
  left: 33.3333333333%; }

#jsxc_dialog .col-xs-push-5, #jsxc_webrtc .col-xs-push-5 {
  left: 41.6666666667%; }

#jsxc_dialog .col-xs-push-6, #jsxc_webrtc .col-xs-push-6 {
  left: 50%; }

#jsxc_dialog .col-xs-push-7, #jsxc_webrtc .col-xs-push-7 {
  left: 58.3333333333%; }

#jsxc_dialog .col-xs-push-8, #jsxc_webrtc .col-xs-push-8 {
  left: 66.6666666667%; }

#jsxc_dialog .col-xs-push-9, #jsxc_webrtc .col-xs-push-9 {
  left: 75%; }

#jsxc_dialog .col-xs-push-10, #jsxc_webrtc .col-xs-push-10 {
  left: 83.3333333333%; }

#jsxc_dialog .col-xs-push-11, #jsxc_webrtc .col-xs-push-11 {
  left: 91.6666666667%; }

#jsxc_dialog .col-xs-push-12, #jsxc_webrtc .col-xs-push-12 {
  left: 100%; }

#jsxc_dialog .col-xs-offset-0, #jsxc_webrtc .col-xs-offset-0 {
  margin-left: 0%; }

#jsxc_dialog .col-xs-offset-1, #jsxc_webrtc .col-xs-offset-1 {
  margin-left: 8.3333333333%; }

#jsxc_dialog .col-xs-offset-2, #jsxc_webrtc .col-xs-offset-2 {
  margin-left: 16.6666666667%; }

#jsxc_dialog .col-xs-offset-3, #jsxc_webrtc .col-xs-offset-3 {
  margin-left: 25%; }

#jsxc_dialog .col-xs-offset-4, #jsxc_webrtc .col-xs-offset-4 {
  margin-left: 33.3333333333%; }

#jsxc_dialog .col-xs-offset-5, #jsxc_webrtc .col-xs-offset-5 {
  margin-left: 41.6666666667%; }

#jsxc_dialog .col-xs-offset-6, #jsxc_webrtc .col-xs-offset-6 {
  margin-left: 50%; }

#jsxc_dialog .col-xs-offset-7, #jsxc_webrtc .col-xs-offset-7 {
  margin-left: 58.3333333333%; }

#jsxc_dialog .col-xs-offset-8, #jsxc_webrtc .col-xs-offset-8 {
  margin-left: 66.6666666667%; }

#jsxc_dialog .col-xs-offset-9, #jsxc_webrtc .col-xs-offset-9 {
  margin-left: 75%; }

#jsxc_dialog .col-xs-offset-10, #jsxc_webrtc .col-xs-offset-10 {
  margin-left: 83.3333333333%; }

#jsxc_dialog .col-xs-offset-11, #jsxc_webrtc .col-xs-offset-11 {
  margin-left: 91.6666666667%; }

#jsxc_dialog .col-xs-offset-12, #jsxc_webrtc .col-xs-offset-12 {
  margin-left: 100%; }

@media (min-width: 768px) {
  #jsxc_dialog .col-sm-1, #jsxc_dialog .col-sm-2, #jsxc_dialog .col-sm-3, #jsxc_dialog .col-sm-4, #jsxc_dialog .col-sm-5, #jsxc_dialog .col-sm-6, #jsxc_dialog .col-sm-7, #jsxc_dialog .col-sm-8, #jsxc_dialog .col-sm-9, #jsxc_dialog .col-sm-10, #jsxc_dialog .col-sm-11, #jsxc_dialog .col-sm-12, #jsxc_webrtc .col-sm-1, #jsxc_webrtc .col-sm-2, #jsxc_webrtc .col-sm-3, #jsxc_webrtc .col-sm-4, #jsxc_webrtc .col-sm-5, #jsxc_webrtc .col-sm-6, #jsxc_webrtc .col-sm-7, #jsxc_webrtc .col-sm-8, #jsxc_webrtc .col-sm-9, #jsxc_webrtc .col-sm-10, #jsxc_webrtc .col-sm-11, #jsxc_webrtc .col-sm-12 {
    float: left; }
  #jsxc_dialog .col-sm-1, #jsxc_webrtc .col-sm-1 {
    width: 8.3333333333%; }
  #jsxc_dialog .col-sm-2, #jsxc_webrtc .col-sm-2 {
    width: 16.6666666667%; }
  #jsxc_dialog .col-sm-3, #jsxc_webrtc .col-sm-3 {
    width: 25%; }
  #jsxc_dialog .col-sm-4, #jsxc_webrtc .col-sm-4 {
    width: 33.3333333333%; }
  #jsxc_dialog .col-sm-5, #jsxc_webrtc .col-sm-5 {
    width: 41.6666666667%; }
  #jsxc_dialog .col-sm-6, #jsxc_webrtc .col-sm-6 {
    width: 50%; }
  #jsxc_dialog .col-sm-7, #jsxc_webrtc .col-sm-7 {
    width: 58.3333333333%; }
  #jsxc_dialog .col-sm-8, #jsxc_webrtc .col-sm-8 {
    width: 66.6666666667%; }
  #jsxc_dialog .col-sm-9, #jsxc_webrtc .col-sm-9 {
    width: 75%; }
  #jsxc_dialog .col-sm-10, #jsxc_webrtc .col-sm-10 {
    width: 83.3333333333%; }
  #jsxc_dialog .col-sm-11, #jsxc_webrtc .col-sm-11 {
    width: 91.6666666667%; }
  #jsxc_dialog .col-sm-12, #jsxc_webrtc .col-sm-12 {
    width: 100%; }
  #jsxc_dialog .col-sm-pull-0, #jsxc_webrtc .col-sm-pull-0 {
    right: auto; }
  #jsxc_dialog .col-sm-pull-1, #jsxc_webrtc .col-sm-pull-1 {
    right: 8.3333333333%; }
  #jsxc_dialog .col-sm-pull-2, #jsxc_webrtc .col-sm-pull-2 {
    right: 16.6666666667%; }
  #jsxc_dialog .col-sm-pull-3, #jsxc_webrtc .col-sm-pull-3 {
    right: 25%; }
  #jsxc_dialog .col-sm-pull-4, #jsxc_webrtc .col-sm-pull-4 {
    right: 33.3333333333%; }
  #jsxc_dialog .col-sm-pull-5, #jsxc_webrtc .col-sm-pull-5 {
    right: 41.6666666667%; }
  #jsxc_dialog .col-sm-pull-6, #jsxc_webrtc .col-sm-pull-6 {
    right: 50%; }
  #jsxc_dialog .col-sm-pull-7, #jsxc_webrtc .col-sm-pull-7 {
    right: 58.3333333333%; }
  #jsxc_dialog .col-sm-pull-8, #jsxc_webrtc .col-sm-pull-8 {
    right: 66.6666666667%; }
  #jsxc_dialog .col-sm-pull-9, #jsxc_webrtc .col-sm-pull-9 {
    right: 75%; }
  #jsxc_dialog .col-sm-pull-10, #jsxc_webrtc .col-sm-pull-10 {
    right: 83.3333333333%; }
  #jsxc_dialog .col-sm-pull-11, #jsxc_webrtc .col-sm-pull-11 {
    right: 91.6666666667%; }
  #jsxc_dialog .col-sm-pull-12, #jsxc_webrtc .col-sm-pull-12 {
    right: 100%; }
  #jsxc_dialog .col-sm-push-0, #jsxc_webrtc .col-sm-push-0 {
    left: auto; }
  #jsxc_dialog .col-sm-push-1, #jsxc_webrtc .col-sm-push-1 {
    left: 8.3333333333%; }
  #jsxc_dialog .col-sm-push-2, #jsxc_webrtc .col-sm-push-2 {
    left: 16.6666666667%; }
  #jsxc_dialog .col-sm-push-3, #jsxc_webrtc .col-sm-push-3 {
    left: 25%; }
  #jsxc_dialog .col-sm-push-4, #jsxc_webrtc .col-sm-push-4 {
    left: 33.3333333333%; }
  #jsxc_dialog .col-sm-push-5, #jsxc_webrtc .col-sm-push-5 {
    left: 41.6666666667%; }
  #jsxc_dialog .col-sm-push-6, #jsxc_webrtc .col-sm-push-6 {
    left: 50%; }
  #jsxc_dialog .col-sm-push-7, #jsxc_webrtc .col-sm-push-7 {
    left: 58.3333333333%; }
  #jsxc_dialog .col-sm-push-8, #jsxc_webrtc .col-sm-push-8 {
    left: 66.6666666667%; }
  #jsxc_dialog .col-sm-push-9, #jsxc_webrtc .col-sm-push-9 {
    left: 75%; }
  #jsxc_dialog .col-sm-push-10, #jsxc_webrtc .col-sm-push-10 {
    left: 83.3333333333%; }
  #jsxc_dialog .col-sm-push-11, #jsxc_webrtc .col-sm-push-11 {
    left: 91.6666666667%; }
  #jsxc_dialog .col-sm-push-12, #jsxc_webrtc .col-sm-push-12 {
    left: 100%; }
  #jsxc_dialog .col-sm-offset-0, #jsxc_webrtc .col-sm-offset-0 {
    margin-left: 0%; }
  #jsxc_dialog .col-sm-offset-1, #jsxc_webrtc .col-sm-offset-1 {
    margin-left: 8.3333333333%; }
  #jsxc_dialog .col-sm-offset-2, #jsxc_webrtc .col-sm-offset-2 {
    margin-left: 16.6666666667%; }
  #jsxc_dialog .col-sm-offset-3, #jsxc_webrtc .col-sm-offset-3 {
    margin-left: 25%; }
  #jsxc_dialog .col-sm-offset-4, #jsxc_webrtc .col-sm-offset-4 {
    margin-left: 33.3333333333%; }
  #jsxc_dialog .col-sm-offset-5, #jsxc_webrtc .col-sm-offset-5 {
    margin-left: 41.6666666667%; }
  #jsxc_dialog .col-sm-offset-6, #jsxc_webrtc .col-sm-offset-6 {
    margin-left: 50%; }
  #jsxc_dialog .col-sm-offset-7, #jsxc_webrtc .col-sm-offset-7 {
    margin-left: 58.3333333333%; }
  #jsxc_dialog .col-sm-offset-8, #jsxc_webrtc .col-sm-offset-8 {
    margin-left: 66.6666666667%; }
  #jsxc_dialog .col-sm-offset-9, #jsxc_webrtc .col-sm-offset-9 {
    margin-left: 75%; }
  #jsxc_dialog .col-sm-offset-10, #jsxc_webrtc .col-sm-offset-10 {
    margin-left: 83.3333333333%; }
  #jsxc_dialog .col-sm-offset-11, #jsxc_webrtc .col-sm-offset-11 {
    margin-left: 91.6666666667%; }
  #jsxc_dialog .col-sm-offset-12, #jsxc_webrtc .col-sm-offset-12 {
    margin-left: 100%; } }

@media (min-width: 992px) {
  #jsxc_dialog .col-md-1, #jsxc_dialog .col-md-2, #jsxc_dialog .col-md-3, #jsxc_dialog .col-md-4, #jsxc_dialog .col-md-5, #jsxc_dialog .col-md-6, #jsxc_dialog .col-md-7, #jsxc_dialog .col-md-8, #jsxc_dialog .col-md-9, #jsxc_dialog .col-md-10, #jsxc_dialog .col-md-11, #jsxc_dialog .col-md-12, #jsxc_webrtc .col-md-1, #jsxc_webrtc .col-md-2, #jsxc_webrtc .col-md-3, #jsxc_webrtc .col-md-4, #jsxc_webrtc .col-md-5, #jsxc_webrtc .col-md-6, #jsxc_webrtc .col-md-7, #jsxc_webrtc .col-md-8, #jsxc_webrtc .col-md-9, #jsxc_webrtc .col-md-10, #jsxc_webrtc .col-md-11, #jsxc_webrtc .col-md-12 {
    float: left; }
  #jsxc_dialog .col-md-1, #jsxc_webrtc .col-md-1 {
    width: 8.3333333333%; }
  #jsxc_dialog .col-md-2, #jsxc_webrtc .col-md-2 {
    width: 16.6666666667%; }
  #jsxc_dialog .col-md-3, #jsxc_webrtc .col-md-3 {
    width: 25%; }
  #jsxc_dialog .col-md-4, #jsxc_webrtc .col-md-4 {
    width: 33.3333333333%; }
  #jsxc_dialog .col-md-5, #jsxc_webrtc .col-md-5 {
    width: 41.6666666667%; }
  #jsxc_dialog .col-md-6, #jsxc_webrtc .col-md-6 {
    width: 50%; }
  #jsxc_dialog .col-md-7, #jsxc_webrtc .col-md-7 {
    width: 58.3333333333%; }
  #jsxc_dialog .col-md-8, #jsxc_webrtc .col-md-8 {
    width: 66.6666666667%; }
  #jsxc_dialog .col-md-9, #jsxc_webrtc .col-md-9 {
    width: 75%; }
  #jsxc_dialog .col-md-10, #jsxc_webrtc .col-md-10 {
    width: 83.3333333333%; }
  #jsxc_dialog .col-md-11, #jsxc_webrtc .col-md-11 {
    width: 91.6666666667%; }
  #jsxc_dialog .col-md-12, #jsxc_webrtc .col-md-12 {
    width: 100%; }
  #jsxc_dialog .col-md-pull-0, #jsxc_webrtc .col-md-pull-0 {
    right: auto; }
  #jsxc_dialog .col-md-pull-1, #jsxc_webrtc .col-md-pull-1 {
    right: 8.3333333333%; }
  #jsxc_dialog .col-md-pull-2, #jsxc_webrtc .col-md-pull-2 {
    right: 16.6666666667%; }
  #jsxc_dialog .col-md-pull-3, #jsxc_webrtc .col-md-pull-3 {
    right: 25%; }
  #jsxc_dialog .col-md-pull-4, #jsxc_webrtc .col-md-pull-4 {
    right: 33.3333333333%; }
  #jsxc_dialog .col-md-pull-5, #jsxc_webrtc .col-md-pull-5 {
    right: 41.6666666667%; }
  #jsxc_dialog .col-md-pull-6, #jsxc_webrtc .col-md-pull-6 {
    right: 50%; }
  #jsxc_dialog .col-md-pull-7, #jsxc_webrtc .col-md-pull-7 {
    right: 58.3333333333%; }
  #jsxc_dialog .col-md-pull-8, #jsxc_webrtc .col-md-pull-8 {
    right: 66.6666666667%; }
  #jsxc_dialog .col-md-pull-9, #jsxc_webrtc .col-md-pull-9 {
    right: 75%; }
  #jsxc_dialog .col-md-pull-10, #jsxc_webrtc .col-md-pull-10 {
    right: 83.3333333333%; }
  #jsxc_dialog .col-md-pull-11, #jsxc_webrtc .col-md-pull-11 {
    right: 91.6666666667%; }
  #jsxc_dialog .col-md-pull-12, #jsxc_webrtc .col-md-pull-12 {
    right: 100%; }
  #jsxc_dialog .col-md-push-0, #jsxc_webrtc .col-md-push-0 {
    left: auto; }
  #jsxc_dialog .col-md-push-1, #jsxc_webrtc .col-md-push-1 {
    left: 8.3333333333%; }
  #jsxc_dialog .col-md-push-2, #jsxc_webrtc .col-md-push-2 {
    left: 16.6666666667%; }
  #jsxc_dialog .col-md-push-3, #jsxc_webrtc .col-md-push-3 {
    left: 25%; }
  #jsxc_dialog .col-md-push-4, #jsxc_webrtc .col-md-push-4 {
    left: 33.3333333333%; }
  #jsxc_dialog .col-md-push-5, #jsxc_webrtc .col-md-push-5 {
    left: 41.6666666667%; }
  #jsxc_dialog .col-md-push-6, #jsxc_webrtc .col-md-push-6 {
    left: 50%; }
  #jsxc_dialog .col-md-push-7, #jsxc_webrtc .col-md-push-7 {
    left: 58.3333333333%; }
  #jsxc_dialog .col-md-push-8, #jsxc_webrtc .col-md-push-8 {
    left: 66.6666666667%; }
  #jsxc_dialog .col-md-push-9, #jsxc_webrtc .col-md-push-9 {
    left: 75%; }
  #jsxc_dialog .col-md-push-10, #jsxc_webrtc .col-md-push-10 {
    left: 83.3333333333%; }
  #jsxc_dialog .col-md-push-11, #jsxc_webrtc .col-md-push-11 {
    left: 91.6666666667%; }
  #jsxc_dialog .col-md-push-12, #jsxc_webrtc .col-md-push-12 {
    left: 100%; }
  #jsxc_dialog .col-md-offset-0, #jsxc_webrtc .col-md-offset-0 {
    margin-left: 0%; }
  #jsxc_dialog .col-md-offset-1, #jsxc_webrtc .col-md-offset-1 {
    margin-left: 8.3333333333%; }
  #jsxc_dialog .col-md-offset-2, #jsxc_webrtc .col-md-offset-2 {
    margin-left: 16.6666666667%; }
  #jsxc_dialog .col-md-offset-3, #jsxc_webrtc .col-md-offset-3 {
    margin-left: 25%; }
  #jsxc_dialog .col-md-offset-4, #jsxc_webrtc .col-md-offset-4 {
    margin-left: 33.3333333333%; }
  #jsxc_dialog .col-md-offset-5, #jsxc_webrtc .col-md-offset-5 {
    margin-left: 41.6666666667%; }
  #jsxc_dialog .col-md-offset-6, #jsxc_webrtc .col-md-offset-6 {
    margin-left: 50%; }
  #jsxc_dialog .col-md-offset-7, #jsxc_webrtc .col-md-offset-7 {
    margin-left: 58.3333333333%; }
  #jsxc_dialog .col-md-offset-8, #jsxc_webrtc .col-md-offset-8 {
    margin-left: 66.6666666667%; }
  #jsxc_dialog .col-md-offset-9, #jsxc_webrtc .col-md-offset-9 {
    margin-left: 75%; }
  #jsxc_dialog .col-md-offset-10, #jsxc_webrtc .col-md-offset-10 {
    margin-left: 83.3333333333%; }
  #jsxc_dialog .col-md-offset-11, #jsxc_webrtc .col-md-offset-11 {
    margin-left: 91.6666666667%; }
  #jsxc_dialog .col-md-offset-12, #jsxc_webrtc .col-md-offset-12 {
    margin-left: 100%; } }

@media (min-width: 1200px) {
  #jsxc_dialog .col-lg-1, #jsxc_dialog .col-lg-2, #jsxc_dialog .col-lg-3, #jsxc_dialog .col-lg-4, #jsxc_dialog .col-lg-5, #jsxc_dialog .col-lg-6, #jsxc_dialog .col-lg-7, #jsxc_dialog .col-lg-8, #jsxc_dialog .col-lg-9, #jsxc_dialog .col-lg-10, #jsxc_dialog .col-lg-11, #jsxc_dialog .col-lg-12, #jsxc_webrtc .col-lg-1, #jsxc_webrtc .col-lg-2, #jsxc_webrtc .col-lg-3, #jsxc_webrtc .col-lg-4, #jsxc_webrtc .col-lg-5, #jsxc_webrtc .col-lg-6, #jsxc_webrtc .col-lg-7, #jsxc_webrtc .col-lg-8, #jsxc_webrtc .col-lg-9, #jsxc_webrtc .col-lg-10, #jsxc_webrtc .col-lg-11, #jsxc_webrtc .col-lg-12 {
    float: left; }
  #jsxc_dialog .col-lg-1, #jsxc_webrtc .col-lg-1 {
    width: 8.3333333333%; }
  #jsxc_dialog .col-lg-2, #jsxc_webrtc .col-lg-2 {
    width: 16.6666666667%; }
  #jsxc_dialog .col-lg-3, #jsxc_webrtc .col-lg-3 {
    width: 25%; }
  #jsxc_dialog .col-lg-4, #jsxc_webrtc .col-lg-4 {
    width: 33.3333333333%; }
  #jsxc_dialog .col-lg-5, #jsxc_webrtc .col-lg-5 {
    width: 41.6666666667%; }
  #jsxc_dialog .col-lg-6, #jsxc_webrtc .col-lg-6 {
    width: 50%; }
  #jsxc_dialog .col-lg-7, #jsxc_webrtc .col-lg-7 {
    width: 58.3333333333%; }
  #jsxc_dialog .col-lg-8, #jsxc_webrtc .col-lg-8 {
    width: 66.6666666667%; }
  #jsxc_dialog .col-lg-9, #jsxc_webrtc .col-lg-9 {
    width: 75%; }
  #jsxc_dialog .col-lg-10, #jsxc_webrtc .col-lg-10 {
    width: 83.3333333333%; }
  #jsxc_dialog .col-lg-11, #jsxc_webrtc .col-lg-11 {
    width: 91.6666666667%; }
  #jsxc_dialog .col-lg-12, #jsxc_webrtc .col-lg-12 {
    width: 100%; }
  #jsxc_dialog .col-lg-pull-0, #jsxc_webrtc .col-lg-pull-0 {
    right: auto; }
  #jsxc_dialog .col-lg-pull-1, #jsxc_webrtc .col-lg-pull-1 {
    right: 8.3333333333%; }
  #jsxc_dialog .col-lg-pull-2, #jsxc_webrtc .col-lg-pull-2 {
    right: 16.6666666667%; }
  #jsxc_dialog .col-lg-pull-3, #jsxc_webrtc .col-lg-pull-3 {
    right: 25%; }
  #jsxc_dialog .col-lg-pull-4, #jsxc_webrtc .col-lg-pull-4 {
    right: 33.3333333333%; }
  #jsxc_dialog .col-lg-pull-5, #jsxc_webrtc .col-lg-pull-5 {
    right: 41.6666666667%; }
  #jsxc_dialog .col-lg-pull-6, #jsxc_webrtc .col-lg-pull-6 {
    right: 50%; }
  #jsxc_dialog .col-lg-pull-7, #jsxc_webrtc .col-lg-pull-7 {
    right: 58.3333333333%; }
  #jsxc_dialog .col-lg-pull-8, #jsxc_webrtc .col-lg-pull-8 {
    right: 66.6666666667%; }
  #jsxc_dialog .col-lg-pull-9, #jsxc_webrtc .col-lg-pull-9 {
    right: 75%; }
  #jsxc_dialog .col-lg-pull-10, #jsxc_webrtc .col-lg-pull-10 {
    right: 83.3333333333%; }
  #jsxc_dialog .col-lg-pull-11, #jsxc_webrtc .col-lg-pull-11 {
    right: 91.6666666667%; }
  #jsxc_dialog .col-lg-pull-12, #jsxc_webrtc .col-lg-pull-12 {
    right: 100%; }
  #jsxc_dialog .col-lg-push-0, #jsxc_webrtc .col-lg-push-0 {
    left: auto; }
  #jsxc_dialog .col-lg-push-1, #jsxc_webrtc .col-lg-push-1 {
    left: 8.3333333333%; }
  #jsxc_dialog .col-lg-push-2, #jsxc_webrtc .col-lg-push-2 {
    left: 16.6666666667%; }
  #jsxc_dialog .col-lg-push-3, #jsxc_webrtc .col-lg-push-3 {
    left: 25%; }
  #jsxc_dialog .col-lg-push-4, #jsxc_webrtc .col-lg-push-4 {
    left: 33.3333333333%; }
  #jsxc_dialog .col-lg-push-5, #jsxc_webrtc .col-lg-push-5 {
    left: 41.6666666667%; }
  #jsxc_dialog .col-lg-push-6, #jsxc_webrtc .col-lg-push-6 {
    left: 50%; }
  #jsxc_dialog .col-lg-push-7, #jsxc_webrtc .col-lg-push-7 {
    left: 58.3333333333%; }
  #jsxc_dialog .col-lg-push-8, #jsxc_webrtc .col-lg-push-8 {
    left: 66.6666666667%; }
  #jsxc_dialog .col-lg-push-9, #jsxc_webrtc .col-lg-push-9 {
    left: 75%; }
  #jsxc_dialog .col-lg-push-10, #jsxc_webrtc .col-lg-push-10 {
    left: 83.3333333333%; }
  #jsxc_dialog .col-lg-push-11, #jsxc_webrtc .col-lg-push-11 {
    left: 91.6666666667%; }
  #jsxc_dialog .col-lg-push-12, #jsxc_webrtc .col-lg-push-12 {
    left: 100%; }
  #jsxc_dialog .col-lg-offset-0, #jsxc_webrtc .col-lg-offset-0 {
    margin-left: 0%; }
  #jsxc_dialog .col-lg-offset-1, #jsxc_webrtc .col-lg-offset-1 {
    margin-left: 8.3333333333%; }
  #jsxc_dialog .col-lg-offset-2, #jsxc_webrtc .col-lg-offset-2 {
    margin-left: 16.6666666667%; }
  #jsxc_dialog .col-lg-offset-3, #jsxc_webrtc .col-lg-offset-3 {
    margin-left: 25%; }
  #jsxc_dialog .col-lg-offset-4, #jsxc_webrtc .col-lg-offset-4 {
    margin-left: 33.3333333333%; }
  #jsxc_dialog .col-lg-offset-5, #jsxc_webrtc .col-lg-offset-5 {
    margin-left: 41.6666666667%; }
  #jsxc_dialog .col-lg-offset-6, #jsxc_webrtc .col-lg-offset-6 {
    margin-left: 50%; }
  #jsxc_dialog .col-lg-offset-7, #jsxc_webrtc .col-lg-offset-7 {
    margin-left: 58.3333333333%; }
  #jsxc_dialog .col-lg-offset-8, #jsxc_webrtc .col-lg-offset-8 {
    margin-left: 66.6666666667%; }
  #jsxc_dialog .col-lg-offset-9, #jsxc_webrtc .col-lg-offset-9 {
    margin-left: 75%; }
  #jsxc_dialog .col-lg-offset-10, #jsxc_webrtc .col-lg-offset-10 {
    margin-left: 83.3333333333%; }
  #jsxc_dialog .col-lg-offset-11, #jsxc_webrtc .col-lg-offset-11 {
    margin-left: 91.6666666667%; }
  #jsxc_dialog .col-lg-offset-12, #jsxc_webrtc .col-lg-offset-12 {
    margin-left: 100%; } }

#jsxc_dialog .alert, #jsxc_webrtc .alert {
  padding: 15px;
  margin-bottom: 20px;
  border: 1px solid transparent;
  border-radius: 4px; }
  #jsxc_dialog .alert h4, #jsxc_webrtc .alert h4 {
    margin-top: 0;
    color: inherit; }
  #jsxc_dialog .alert .alert-link, #jsxc_webrtc .alert .alert-link {
    font-weight: bold; }
  #jsxc_dialog .alert > p,
  #jsxc_dialog .alert > ul, #jsxc_webrtc .alert > p,
  #jsxc_webrtc .alert > ul {
    margin-bottom: 0; }
  #jsxc_dialog .alert > p + p, #jsxc_webrtc .alert > p + p {
    margin-top: 5px; }

#jsxc_dialog .alert-dismissable,
#jsxc_dialog .alert-dismissible, #jsxc_webrtc .alert-dismissable,
#jsxc_webrtc .alert-dismissible {
  padding-right: 35px; }
  #jsxc_dialog .alert-dismissable .close,
  #jsxc_dialog .alert-dismissible .close, #jsxc_webrtc .alert-dismissable .close,
  #jsxc_webrtc .alert-dismissible .close {
    position: relative;
    top: -2px;
    right: -21px;
    color: inherit; }

#jsxc_dialog .alert-success, #jsxc_webrtc .alert-success {
  background-color: #dff0d8;
  border-color: #d6e9c6;
  color: #3c763d; }
  #jsxc_dialog .alert-success hr, #jsxc_webrtc .alert-success hr {
    border-top-color: #c9e2b3; }
  #jsxc_dialog .alert-success .alert-link, #jsxc_webrtc .alert-success .alert-link {
    color: #2b542c; }

#jsxc_dialog .alert-info, #jsxc_webrtc .alert-info {
  background-color: #d9edf7;
  border-color: #bce8f1;
  color: #31708f; }
  #jsxc_dialog .alert-info hr, #jsxc_webrtc .alert-info hr {
    border-top-color: #a6e1ec; }
  #jsxc_dialog .alert-info .alert-link, #jsxc_webrtc .alert-info .alert-link {
    color: #245269; }

#jsxc_dialog .alert-warning, #jsxc_webrtc .alert-warning {
  background-color: #fcf8e3;
  border-color: #faebcc;
  color: #8a6d3b; }
  #jsxc_dialog .alert-warning hr, #jsxc_webrtc .alert-warning hr {
    border-top-color: #f7e1b5; }
  #jsxc_dialog .alert-warning .alert-link, #jsxc_webrtc .alert-warning .alert-link {
    color: #66512c; }

#jsxc_dialog .alert-danger, #jsxc_webrtc .alert-danger {
  background-color: #f2dede;
  border-color: #ebccd1;
  color: #a94442; }
  #jsxc_dialog .alert-danger hr, #jsxc_webrtc .alert-danger hr {
    border-top-color: #e4b9c0; }
  #jsxc_dialog .alert-danger .alert-link, #jsxc_webrtc .alert-danger .alert-link {
    color: #843534; }

#jsxc_dialog .btn, #jsxc_webrtc .btn {
  display: inline-block;
  margin-bottom: 0;
  font-weight: normal;
  text-align: center;
  vertical-align: middle;
  -ms-touch-action: manipulation;
      touch-action: manipulation;
  cursor: pointer;
  background-image: none;
  border: 1px solid transparent;
  white-space: nowrap;
  padding: 6px 12px;
  font-size: 14px;
  line-height: 1.428571429;
  border-radius: 4px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }
  #jsxc_dialog .btn:focus, #jsxc_dialog .btn.focus, #jsxc_dialog .btn:active:focus, #jsxc_dialog .btn:active.focus, #jsxc_dialog .btn.active:focus, #jsxc_dialog .btn.active.focus, #jsxc_webrtc .btn:focus, #jsxc_webrtc .btn.focus, #jsxc_webrtc .btn:active:focus, #jsxc_webrtc .btn:active.focus, #jsxc_webrtc .btn.active:focus, #jsxc_webrtc .btn.active.focus {
    outline: thin dotted;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px; }
  #jsxc_dialog .btn:hover, #jsxc_dialog .btn:focus, #jsxc_dialog .btn.focus, #jsxc_webrtc .btn:hover, #jsxc_webrtc .btn:focus, #jsxc_webrtc .btn.focus {
    color: #333;
    text-decoration: none; }
  #jsxc_dialog .btn:active, #jsxc_dialog .btn.active, #jsxc_webrtc .btn:active, #jsxc_webrtc .btn.active {
    outline: 0;
    background-image: none;
    box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125); }
  #jsxc_dialog .btn.disabled, #jsxc_dialog .btn[disabled],
  fieldset[disabled] #jsxc_dialog .btn, #jsxc_webrtc .btn.disabled, #jsxc_webrtc .btn[disabled],
  fieldset[disabled] #jsxc_webrtc .btn {
    cursor: not-allowed;
    pointer-events: none;
    opacity: 0.65;
    filter: alpha(opacity=65);
    box-shadow: none; }

#jsxc_dialog .btn-default, #jsxc_webrtc .btn-default {
  color: #333;
  background-color: #fff;
  border-color: #ccc; }
  #jsxc_dialog .btn-default:hover, #jsxc_dialog .btn-default:focus, #jsxc_dialog .btn-default.focus, #jsxc_dialog .btn-default:active, #jsxc_dialog .btn-default.active,
  .open > #jsxc_dialog .btn-default.dropdown-toggle, #jsxc_webrtc .btn-default:hover, #jsxc_webrtc .btn-default:focus, #jsxc_webrtc .btn-default.focus, #jsxc_webrtc .btn-default:active, #jsxc_webrtc .btn-default.active,
  .open > #jsxc_webrtc .btn-default.dropdown-toggle {
    color: #333;
    background-color: #e6e6e6;
    border-color: #adadad; }
  #jsxc_dialog .btn-default:active, #jsxc_dialog .btn-default.active,
  .open > #jsxc_dialog .btn-default.dropdown-toggle, #jsxc_webrtc .btn-default:active, #jsxc_webrtc .btn-default.active,
  .open > #jsxc_webrtc .btn-default.dropdown-toggle {
    background-image: none; }
  #jsxc_dialog .btn-default.disabled, #jsxc_dialog .btn-default.disabled:hover, #jsxc_dialog .btn-default.disabled:focus, #jsxc_dialog .btn-default.disabled.focus, #jsxc_dialog .btn-default.disabled:active, #jsxc_dialog .btn-default.disabled.active, #jsxc_dialog .btn-default[disabled], #jsxc_dialog .btn-default[disabled]:hover, #jsxc_dialog .btn-default[disabled]:focus, #jsxc_dialog .btn-default[disabled].focus, #jsxc_dialog .btn-default[disabled]:active, #jsxc_dialog .btn-default[disabled].active,
  fieldset[disabled] #jsxc_dialog .btn-default,
  fieldset[disabled] #jsxc_dialog .btn-default:hover,
  fieldset[disabled] #jsxc_dialog .btn-default:focus,
  fieldset[disabled] #jsxc_dialog .btn-default.focus,
  fieldset[disabled] #jsxc_dialog .btn-default:active,
  fieldset[disabled] #jsxc_dialog .btn-default.active, #jsxc_webrtc .btn-default.disabled, #jsxc_webrtc .btn-default.disabled:hover, #jsxc_webrtc .btn-default.disabled:focus, #jsxc_webrtc .btn-default.disabled.focus, #jsxc_webrtc .btn-default.disabled:active, #jsxc_webrtc .btn-default.disabled.active, #jsxc_webrtc .btn-default[disabled], #jsxc_webrtc .btn-default[disabled]:hover, #jsxc_webrtc .btn-default[disabled]:focus, #jsxc_webrtc .btn-default[disabled].focus, #jsxc_webrtc .btn-default[disabled]:active, #jsxc_webrtc .btn-default[disabled].active,
  fieldset[disabled] #jsxc_webrtc .btn-default,
  fieldset[disabled] #jsxc_webrtc .btn-default:hover,
  fieldset[disabled] #jsxc_webrtc .btn-default:focus,
  fieldset[disabled] #jsxc_webrtc .btn-default.focus,
  fieldset[disabled] #jsxc_webrtc .btn-default:active,
  fieldset[disabled] #jsxc_webrtc .btn-default.active {
    background-color: #fff;
    border-color: #ccc; }
  #jsxc_dialog .btn-default .badge, #jsxc_webrtc .btn-default .badge {
    color: #fff;
    background-color: #333; }

#jsxc_dialog .btn-primary, #jsxc_webrtc .btn-primary {
  color: #fff;
  background-color: #337ab7;
  border-color: #2e6da4; }
  #jsxc_dialog .btn-primary:hover, #jsxc_dialog .btn-primary:focus, #jsxc_dialog .btn-primary.focus, #jsxc_dialog .btn-primary:active, #jsxc_dialog .btn-primary.active,
  .open > #jsxc_dialog .btn-primary.dropdown-toggle, #jsxc_webrtc .btn-primary:hover, #jsxc_webrtc .btn-primary:focus, #jsxc_webrtc .btn-primary.focus, #jsxc_webrtc .btn-primary:active, #jsxc_webrtc .btn-primary.active,
  .open > #jsxc_webrtc .btn-primary.dropdown-toggle {
    color: #fff;
    background-color: #286090;
    border-color: #204d74; }
  #jsxc_dialog .btn-primary:active, #jsxc_dialog .btn-primary.active,
  .open > #jsxc_dialog .btn-primary.dropdown-toggle, #jsxc_webrtc .btn-primary:active, #jsxc_webrtc .btn-primary.active,
  .open > #jsxc_webrtc .btn-primary.dropdown-toggle {
    background-image: none; }
  #jsxc_dialog .btn-primary.disabled, #jsxc_dialog .btn-primary.disabled:hover, #jsxc_dialog .btn-primary.disabled:focus, #jsxc_dialog .btn-primary.disabled.focus, #jsxc_dialog .btn-primary.disabled:active, #jsxc_dialog .btn-primary.disabled.active, #jsxc_dialog .btn-primary[disabled], #jsxc_dialog .btn-primary[disabled]:hover, #jsxc_dialog .btn-primary[disabled]:focus, #jsxc_dialog .btn-primary[disabled].focus, #jsxc_dialog .btn-primary[disabled]:active, #jsxc_dialog .btn-primary[disabled].active,
  fieldset[disabled] #jsxc_dialog .btn-primary,
  fieldset[disabled] #jsxc_dialog .btn-primary:hover,
  fieldset[disabled] #jsxc_dialog .btn-primary:focus,
  fieldset[disabled] #jsxc_dialog .btn-primary.focus,
  fieldset[disabled] #jsxc_dialog .btn-primary:active,
  fieldset[disabled] #jsxc_dialog .btn-primary.active, #jsxc_webrtc .btn-primary.disabled, #jsxc_webrtc .btn-primary.disabled:hover, #jsxc_webrtc .btn-primary.disabled:focus, #jsxc_webrtc .btn-primary.disabled.focus, #jsxc_webrtc .btn-primary.disabled:active, #jsxc_webrtc .btn-primary.disabled.active, #jsxc_webrtc .btn-primary[disabled], #jsxc_webrtc .btn-primary[disabled]:hover, #jsxc_webrtc .btn-primary[disabled]:focus, #jsxc_webrtc .btn-primary[disabled].focus, #jsxc_webrtc .btn-primary[disabled]:active, #jsxc_webrtc .btn-primary[disabled].active,
  fieldset[disabled] #jsxc_webrtc .btn-primary,
  fieldset[disabled] #jsxc_webrtc .btn-primary:hover,
  fieldset[disabled] #jsxc_webrtc .btn-primary:focus,
  fieldset[disabled] #jsxc_webrtc .btn-primary.focus,
  fieldset[disabled] #jsxc_webrtc .btn-primary:active,
  fieldset[disabled] #jsxc_webrtc .btn-primary.active {
    background-color: #337ab7;
    border-color: #2e6da4; }
  #jsxc_dialog .btn-primary .badge, #jsxc_webrtc .btn-primary .badge {
    color: #337ab7;
    background-color: #fff; }

#jsxc_dialog .btn-success, #jsxc_webrtc .btn-success {
  color: #fff;
  background-color: #5cb85c;
  border-color: #4cae4c; }
  #jsxc_dialog .btn-success:hover, #jsxc_dialog .btn-success:focus, #jsxc_dialog .btn-success.focus, #jsxc_dialog .btn-success:active, #jsxc_dialog .btn-success.active,
  .open > #jsxc_dialog .btn-success.dropdown-toggle, #jsxc_webrtc .btn-success:hover, #jsxc_webrtc .btn-success:focus, #jsxc_webrtc .btn-success.focus, #jsxc_webrtc .btn-success:active, #jsxc_webrtc .btn-success.active,
  .open > #jsxc_webrtc .btn-success.dropdown-toggle {
    color: #fff;
    background-color: #449d44;
    border-color: #398439; }
  #jsxc_dialog .btn-success:active, #jsxc_dialog .btn-success.active,
  .open > #jsxc_dialog .btn-success.dropdown-toggle, #jsxc_webrtc .btn-success:active, #jsxc_webrtc .btn-success.active,
  .open > #jsxc_webrtc .btn-success.dropdown-toggle {
    background-image: none; }
  #jsxc_dialog .btn-success.disabled, #jsxc_dialog .btn-success.disabled:hover, #jsxc_dialog .btn-success.disabled:focus, #jsxc_dialog .btn-success.disabled.focus, #jsxc_dialog .btn-success.disabled:active, #jsxc_dialog .btn-success.disabled.active, #jsxc_dialog .btn-success[disabled], #jsxc_dialog .btn-success[disabled]:hover, #jsxc_dialog .btn-success[disabled]:focus, #jsxc_dialog .btn-success[disabled].focus, #jsxc_dialog .btn-success[disabled]:active, #jsxc_dialog .btn-success[disabled].active,
  fieldset[disabled] #jsxc_dialog .btn-success,
  fieldset[disabled] #jsxc_dialog .btn-success:hover,
  fieldset[disabled] #jsxc_dialog .btn-success:focus,
  fieldset[disabled] #jsxc_dialog .btn-success.focus,
  fieldset[disabled] #jsxc_dialog .btn-success:active,
  fieldset[disabled] #jsxc_dialog .btn-success.active, #jsxc_webrtc .btn-success.disabled, #jsxc_webrtc .btn-success.disabled:hover, #jsxc_webrtc .btn-success.disabled:focus, #jsxc_webrtc .btn-success.disabled.focus, #jsxc_webrtc .btn-success.disabled:active, #jsxc_webrtc .btn-success.disabled.active, #jsxc_webrtc .btn-success[disabled], #jsxc_webrtc .btn-success[disabled]:hover, #jsxc_webrtc .btn-success[disabled]:focus, #jsxc_webrtc .btn-success[disabled].focus, #jsxc_webrtc .btn-success[disabled]:active, #jsxc_webrtc .btn-success[disabled].active,
  fieldset[disabled] #jsxc_webrtc .btn-success,
  fieldset[disabled] #jsxc_webrtc .btn-success:hover,
  fieldset[disabled] #jsxc_webrtc .btn-success:focus,
  fieldset[disabled] #jsxc_webrtc .btn-success.focus,
  fieldset[disabled] #jsxc_webrtc .btn-success:active,
  fieldset[disabled] #jsxc_webrtc .btn-success.active {
    background-color: #5cb85c;
    border-color: #4cae4c; }
  #jsxc_dialog .btn-success .badge, #jsxc_webrtc .btn-success .badge {
    color: #5cb85c;
    background-color: #fff; }

#jsxc_dialog .btn-info, #jsxc_webrtc .btn-info {
  color: #fff;
  background-color: #5bc0de;
  border-color: #46b8da; }
  #jsxc_dialog .btn-info:hover, #jsxc_dialog .btn-info:focus, #jsxc_dialog .btn-info.focus, #jsxc_dialog .btn-info:active, #jsxc_dialog .btn-info.active,
  .open > #jsxc_dialog .btn-info.dropdown-toggle, #jsxc_webrtc .btn-info:hover, #jsxc_webrtc .btn-info:focus, #jsxc_webrtc .btn-info.focus, #jsxc_webrtc .btn-info:active, #jsxc_webrtc .btn-info.active,
  .open > #jsxc_webrtc .btn-info.dropdown-toggle {
    color: #fff;
    background-color: #31b0d5;
    border-color: #269abc; }
  #jsxc_dialog .btn-info:active, #jsxc_dialog .btn-info.active,
  .open > #jsxc_dialog .btn-info.dropdown-toggle, #jsxc_webrtc .btn-info:active, #jsxc_webrtc .btn-info.active,
  .open > #jsxc_webrtc .btn-info.dropdown-toggle {
    background-image: none; }
  #jsxc_dialog .btn-info.disabled, #jsxc_dialog .btn-info.disabled:hover, #jsxc_dialog .btn-info.disabled:focus, #jsxc_dialog .btn-info.disabled.focus, #jsxc_dialog .btn-info.disabled:active, #jsxc_dialog .btn-info.disabled.active, #jsxc_dialog .btn-info[disabled], #jsxc_dialog .btn-info[disabled]:hover, #jsxc_dialog .btn-info[disabled]:focus, #jsxc_dialog .btn-info[disabled].focus, #jsxc_dialog .btn-info[disabled]:active, #jsxc_dialog .btn-info[disabled].active,
  fieldset[disabled] #jsxc_dialog .btn-info,
  fieldset[disabled] #jsxc_dialog .btn-info:hover,
  fieldset[disabled] #jsxc_dialog .btn-info:focus,
  fieldset[disabled] #jsxc_dialog .btn-info.focus,
  fieldset[disabled] #jsxc_dialog .btn-info:active,
  fieldset[disabled] #jsxc_dialog .btn-info.active, #jsxc_webrtc .btn-info.disabled, #jsxc_webrtc .btn-info.disabled:hover, #jsxc_webrtc .btn-info.disabled:focus, #jsxc_webrtc .btn-info.disabled.focus, #jsxc_webrtc .btn-info.disabled:active, #jsxc_webrtc .btn-info.disabled.active, #jsxc_webrtc .btn-info[disabled], #jsxc_webrtc .btn-info[disabled]:hover, #jsxc_webrtc .btn-info[disabled]:focus, #jsxc_webrtc .btn-info[disabled].focus, #jsxc_webrtc .btn-info[disabled]:active, #jsxc_webrtc .btn-info[disabled].active,
  fieldset[disabled] #jsxc_webrtc .btn-info,
  fieldset[disabled] #jsxc_webrtc .btn-info:hover,
  fieldset[disabled] #jsxc_webrtc .btn-info:focus,
  fieldset[disabled] #jsxc_webrtc .btn-info.focus,
  fieldset[disabled] #jsxc_webrtc .btn-info:active,
  fieldset[disabled] #jsxc_webrtc .btn-info.active {
    background-color: #5bc0de;
    border-color: #46b8da; }
  #jsxc_dialog .btn-info .badge, #jsxc_webrtc .btn-info .badge {
    color: #5bc0de;
    background-color: #fff; }

#jsxc_dialog .btn-warning, #jsxc_webrtc .btn-warning {
  color: #fff;
  background-color: #f0ad4e;
  border-color: #eea236; }
  #jsxc_dialog .btn-warning:hover, #jsxc_dialog .btn-warning:focus, #jsxc_dialog .btn-warning.focus, #jsxc_dialog .btn-warning:active, #jsxc_dialog .btn-warning.active,
  .open > #jsxc_dialog .btn-warning.dropdown-toggle, #jsxc_webrtc .btn-warning:hover, #jsxc_webrtc .btn-warning:focus, #jsxc_webrtc .btn-warning.focus, #jsxc_webrtc .btn-warning:active, #jsxc_webrtc .btn-warning.active,
  .open > #jsxc_webrtc .btn-warning.dropdown-toggle {
    color: #fff;
    background-color: #ec971f;
    border-color: #d58512; }
  #jsxc_dialog .btn-warning:active, #jsxc_dialog .btn-warning.active,
  .open > #jsxc_dialog .btn-warning.dropdown-toggle, #jsxc_webrtc .btn-warning:active, #jsxc_webrtc .btn-warning.active,
  .open > #jsxc_webrtc .btn-warning.dropdown-toggle {
    background-image: none; }
  #jsxc_dialog .btn-warning.disabled, #jsxc_dialog .btn-warning.disabled:hover, #jsxc_dialog .btn-warning.disabled:focus, #jsxc_dialog .btn-warning.disabled.focus, #jsxc_dialog .btn-warning.disabled:active, #jsxc_dialog .btn-warning.disabled.active, #jsxc_dialog .btn-warning[disabled], #jsxc_dialog .btn-warning[disabled]:hover, #jsxc_dialog .btn-warning[disabled]:focus, #jsxc_dialog .btn-warning[disabled].focus, #jsxc_dialog .btn-warning[disabled]:active, #jsxc_dialog .btn-warning[disabled].active,
  fieldset[disabled] #jsxc_dialog .btn-warning,
  fieldset[disabled] #jsxc_dialog .btn-warning:hover,
  fieldset[disabled] #jsxc_dialog .btn-warning:focus,
  fieldset[disabled] #jsxc_dialog .btn-warning.focus,
  fieldset[disabled] #jsxc_dialog .btn-warning:active,
  fieldset[disabled] #jsxc_dialog .btn-warning.active, #jsxc_webrtc .btn-warning.disabled, #jsxc_webrtc .btn-warning.disabled:hover, #jsxc_webrtc .btn-warning.disabled:focus, #jsxc_webrtc .btn-warning.disabled.focus, #jsxc_webrtc .btn-warning.disabled:active, #jsxc_webrtc .btn-warning.disabled.active, #jsxc_webrtc .btn-warning[disabled], #jsxc_webrtc .btn-warning[disabled]:hover, #jsxc_webrtc .btn-warning[disabled]:focus, #jsxc_webrtc .btn-warning[disabled].focus, #jsxc_webrtc .btn-warning[disabled]:active, #jsxc_webrtc .btn-warning[disabled].active,
  fieldset[disabled] #jsxc_webrtc .btn-warning,
  fieldset[disabled] #jsxc_webrtc .btn-warning:hover,
  fieldset[disabled] #jsxc_webrtc .btn-warning:focus,
  fieldset[disabled] #jsxc_webrtc .btn-warning.focus,
  fieldset[disabled] #jsxc_webrtc .btn-warning:active,
  fieldset[disabled] #jsxc_webrtc .btn-warning.active {
    background-color: #f0ad4e;
    border-color: #eea236; }
  #jsxc_dialog .btn-warning .badge, #jsxc_webrtc .btn-warning .badge {
    color: #f0ad4e;
    background-color: #fff; }

#jsxc_dialog .btn-danger, #jsxc_webrtc .btn-danger {
  color: #fff;
  background-color: #d9534f;
  border-color: #d43f3a; }
  #jsxc_dialog .btn-danger:hover, #jsxc_dialog .btn-danger:focus, #jsxc_dialog .btn-danger.focus, #jsxc_dialog .btn-danger:active, #jsxc_dialog .btn-danger.active,
  .open > #jsxc_dialog .btn-danger.dropdown-toggle, #jsxc_webrtc .btn-danger:hover, #jsxc_webrtc .btn-danger:focus, #jsxc_webrtc .btn-danger.focus, #jsxc_webrtc .btn-danger:active, #jsxc_webrtc .btn-danger.active,
  .open > #jsxc_webrtc .btn-danger.dropdown-toggle {
    color: #fff;
    background-color: #c9302c;
    border-color: #ac2925; }
  #jsxc_dialog .btn-danger:active, #jsxc_dialog .btn-danger.active,
  .open > #jsxc_dialog .btn-danger.dropdown-toggle, #jsxc_webrtc .btn-danger:active, #jsxc_webrtc .btn-danger.active,
  .open > #jsxc_webrtc .btn-danger.dropdown-toggle {
    background-image: none; }
  #jsxc_dialog .btn-danger.disabled, #jsxc_dialog .btn-danger.disabled:hover, #jsxc_dialog .btn-danger.disabled:focus, #jsxc_dialog .btn-danger.disabled.focus, #jsxc_dialog .btn-danger.disabled:active, #jsxc_dialog .btn-danger.disabled.active, #jsxc_dialog .btn-danger[disabled], #jsxc_dialog .btn-danger[disabled]:hover, #jsxc_dialog .btn-danger[disabled]:focus, #jsxc_dialog .btn-danger[disabled].focus, #jsxc_dialog .btn-danger[disabled]:active, #jsxc_dialog .btn-danger[disabled].active,
  fieldset[disabled] #jsxc_dialog .btn-danger,
  fieldset[disabled] #jsxc_dialog .btn-danger:hover,
  fieldset[disabled] #jsxc_dialog .btn-danger:focus,
  fieldset[disabled] #jsxc_dialog .btn-danger.focus,
  fieldset[disabled] #jsxc_dialog .btn-danger:active,
  fieldset[disabled] #jsxc_dialog .btn-danger.active, #jsxc_webrtc .btn-danger.disabled, #jsxc_webrtc .btn-danger.disabled:hover, #jsxc_webrtc .btn-danger.disabled:focus, #jsxc_webrtc .btn-danger.disabled.focus, #jsxc_webrtc .btn-danger.disabled:active, #jsxc_webrtc .btn-danger.disabled.active, #jsxc_webrtc .btn-danger[disabled], #jsxc_webrtc .btn-danger[disabled]:hover, #jsxc_webrtc .btn-danger[disabled]:focus, #jsxc_webrtc .btn-danger[disabled].focus, #jsxc_webrtc .btn-danger[disabled]:active, #jsxc_webrtc .btn-danger[disabled].active,
  fieldset[disabled] #jsxc_webrtc .btn-danger,
  fieldset[disabled] #jsxc_webrtc .btn-danger:hover,
  fieldset[disabled] #jsxc_webrtc .btn-danger:focus,
  fieldset[disabled] #jsxc_webrtc .btn-danger.focus,
  fieldset[disabled] #jsxc_webrtc .btn-danger:active,
  fieldset[disabled] #jsxc_webrtc .btn-danger.active {
    background-color: #d9534f;
    border-color: #d43f3a; }
  #jsxc_dialog .btn-danger .badge, #jsxc_webrtc .btn-danger .badge {
    color: #d9534f;
    background-color: #fff; }

#jsxc_dialog .btn-link, #jsxc_webrtc .btn-link {
  color: #337ab7;
  font-weight: normal;
  border-radius: 0; }
  #jsxc_dialog .btn-link, #jsxc_dialog .btn-link:active, #jsxc_dialog .btn-link.active, #jsxc_dialog .btn-link[disabled],
  fieldset[disabled] #jsxc_dialog .btn-link, #jsxc_webrtc .btn-link, #jsxc_webrtc .btn-link:active, #jsxc_webrtc .btn-link.active, #jsxc_webrtc .btn-link[disabled],
  fieldset[disabled] #jsxc_webrtc .btn-link {
    background-color: transparent;
    box-shadow: none; }
  #jsxc_dialog .btn-link, #jsxc_dialog .btn-link:hover, #jsxc_dialog .btn-link:focus, #jsxc_dialog .btn-link:active, #jsxc_webrtc .btn-link, #jsxc_webrtc .btn-link:hover, #jsxc_webrtc .btn-link:focus, #jsxc_webrtc .btn-link:active {
    border-color: transparent; }
  #jsxc_dialog .btn-link:hover, #jsxc_dialog .btn-link:focus, #jsxc_webrtc .btn-link:hover, #jsxc_webrtc .btn-link:focus {
    color: #23527c;
    text-decoration: underline;
    background-color: transparent; }
  #jsxc_dialog .btn-link[disabled]:hover, #jsxc_dialog .btn-link[disabled]:focus,
  fieldset[disabled] #jsxc_dialog .btn-link:hover,
  fieldset[disabled] #jsxc_dialog .btn-link:focus, #jsxc_webrtc .btn-link[disabled]:hover, #jsxc_webrtc .btn-link[disabled]:focus,
  fieldset[disabled] #jsxc_webrtc .btn-link:hover,
  fieldset[disabled] #jsxc_webrtc .btn-link:focus {
    color: #777777;
    text-decoration: none; }

#jsxc_dialog .btn-lg, #jsxc_dialog .btn-group-lg > .btn, #jsxc_dialog #jsxc_webrtc .btn-group-lg > .btn, #jsxc_webrtc .btn-lg, #jsxc_webrtc #jsxc_dialog .btn-group-lg > .btn, #jsxc_webrtc .btn-group-lg > .btn {
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.3333333;
  border-radius: 6px; }

#jsxc_dialog .btn-sm, #jsxc_dialog .btn-group-sm > .btn, #jsxc_dialog #jsxc_webrtc .btn-group-sm > .btn, #jsxc_webrtc .btn-sm, #jsxc_webrtc #jsxc_dialog .btn-group-sm > .btn, #jsxc_webrtc .btn-group-sm > .btn {
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px; }

#jsxc_dialog .btn-xs, #jsxc_dialog .btn-group-xs > .btn, #jsxc_dialog #jsxc_webrtc .btn-group-xs > .btn, #jsxc_webrtc .btn-xs, #jsxc_webrtc #jsxc_dialog .btn-group-xs > .btn, #jsxc_webrtc .btn-group-xs > .btn {
  padding: 1px 5px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px; }

#jsxc_dialog .btn-block, #jsxc_webrtc .btn-block {
  display: block;
  width: 100%; }

#jsxc_dialog .btn-block + .btn-block, #jsxc_webrtc .btn-block + .btn-block {
  margin-top: 5px; }

#jsxc_dialog input[type="submit"].btn-block,
#jsxc_dialog input[type="reset"].btn-block,
#jsxc_dialog input[type="button"].btn-block, #jsxc_webrtc input[type="submit"].btn-block,
#jsxc_webrtc input[type="reset"].btn-block,
#jsxc_webrtc input[type="button"].btn-block {
  width: 100%; }

#jsxc_dialog .btn-group,
#jsxc_dialog .btn-group-vertical, #jsxc_webrtc .btn-group,
#jsxc_webrtc .btn-group-vertical {
  position: relative;
  display: inline-block;
  vertical-align: middle; }
  #jsxc_dialog .btn-group > .btn,
  #jsxc_dialog .btn-group-vertical > .btn, #jsxc_webrtc .btn-group > .btn,
  #jsxc_webrtc .btn-group-vertical > .btn {
    position: relative;
    float: left; }
    #jsxc_dialog .btn-group > .btn:hover, #jsxc_dialog .btn-group > .btn:focus, #jsxc_dialog .btn-group > .btn:active, #jsxc_dialog .btn-group > .btn.active,
    #jsxc_dialog .btn-group-vertical > .btn:hover,
    #jsxc_dialog .btn-group-vertical > .btn:focus,
    #jsxc_dialog .btn-group-vertical > .btn:active,
    #jsxc_dialog .btn-group-vertical > .btn.active, #jsxc_webrtc .btn-group > .btn:hover, #jsxc_webrtc .btn-group > .btn:focus, #jsxc_webrtc .btn-group > .btn:active, #jsxc_webrtc .btn-group > .btn.active,
    #jsxc_webrtc .btn-group-vertical > .btn:hover,
    #jsxc_webrtc .btn-group-vertical > .btn:focus,
    #jsxc_webrtc .btn-group-vertical > .btn:active,
    #jsxc_webrtc .btn-group-vertical > .btn.active {
      z-index: 2; }

#jsxc_dialog .btn-group .btn + .btn,
#jsxc_dialog .btn-group .btn + .btn-group,
#jsxc_dialog .btn-group .btn-group + .btn,
#jsxc_dialog .btn-group .btn-group + .btn-group, #jsxc_webrtc .btn-group .btn + .btn,
#jsxc_webrtc .btn-group .btn + .btn-group,
#jsxc_webrtc .btn-group .btn-group + .btn,
#jsxc_webrtc .btn-group .btn-group + .btn-group {
  margin-left: -1px; }

#jsxc_dialog .btn-toolbar, #jsxc_webrtc .btn-toolbar {
  margin-left: -5px; }
  #jsxc_dialog .btn-toolbar:before, #jsxc_dialog .btn-toolbar:after, #jsxc_webrtc .btn-toolbar:before, #jsxc_webrtc .btn-toolbar:after {
    content: " ";
    display: table; }
  #jsxc_dialog .btn-toolbar:after, #jsxc_webrtc .btn-toolbar:after {
    clear: both; }
  #jsxc_dialog .btn-toolbar .btn-group,
  #jsxc_dialog .btn-toolbar .input-group, #jsxc_webrtc .btn-toolbar .btn-group,
  #jsxc_webrtc .btn-toolbar .input-group {
    float: left; }
  #jsxc_dialog .btn-toolbar > .btn,
  #jsxc_dialog .btn-toolbar > .btn-group,
  #jsxc_dialog .btn-toolbar > .input-group, #jsxc_webrtc .btn-toolbar > .btn,
  #jsxc_webrtc .btn-toolbar > .btn-group,
  #jsxc_webrtc .btn-toolbar > .input-group {
    margin-left: 5px; }

#jsxc_dialog .btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle), #jsxc_webrtc .btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
  border-radius: 0; }

#jsxc_dialog .btn-group > .btn:first-child, #jsxc_webrtc .btn-group > .btn:first-child {
  margin-left: 0; }
  #jsxc_dialog .btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle), #jsxc_webrtc .btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0; }

#jsxc_dialog .btn-group > .btn:last-child:not(:first-child),
#jsxc_dialog .btn-group > .dropdown-toggle:not(:first-child), #jsxc_webrtc .btn-group > .btn:last-child:not(:first-child),
#jsxc_webrtc .btn-group > .dropdown-toggle:not(:first-child) {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0; }

#jsxc_dialog .btn-group > .btn-group, #jsxc_webrtc .btn-group > .btn-group {
  float: left; }

#jsxc_dialog .btn-group > .btn-group:not(:first-child):not(:last-child) > .btn, #jsxc_webrtc .btn-group > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0; }

#jsxc_dialog .btn-group > .btn-group:first-child:not(:last-child) > .btn:last-child,
#jsxc_dialog .btn-group > .btn-group:first-child:not(:last-child) > .dropdown-toggle, #jsxc_webrtc .btn-group > .btn-group:first-child:not(:last-child) > .btn:last-child,
#jsxc_webrtc .btn-group > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0; }

#jsxc_dialog .btn-group > .btn-group:last-child:not(:first-child) > .btn:first-child, #jsxc_webrtc .btn-group > .btn-group:last-child:not(:first-child) > .btn:first-child {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0; }

#jsxc_dialog .btn-group .dropdown-toggle:active,
#jsxc_dialog .btn-group.open .dropdown-toggle, #jsxc_webrtc .btn-group .dropdown-toggle:active,
#jsxc_webrtc .btn-group.open .dropdown-toggle {
  outline: 0; }

#jsxc_dialog .btn-group > .btn + .dropdown-toggle, #jsxc_webrtc .btn-group > .btn + .dropdown-toggle {
  padding-left: 8px;
  padding-right: 8px; }

#jsxc_dialog .btn-group > .btn-lg + .dropdown-toggle, #jsxc_dialog .btn-group-lg.btn-group > .btn + .dropdown-toggle, #jsxc_dialog #jsxc_webrtc .btn-group-lg.btn-group > .btn + .dropdown-toggle, #jsxc_webrtc .btn-group > .btn-lg + .dropdown-toggle, #jsxc_webrtc #jsxc_dialog .btn-group-lg.btn-group > .btn + .dropdown-toggle, #jsxc_webrtc .btn-group-lg.btn-group > .btn + .dropdown-toggle {
  padding-left: 12px;
  padding-right: 12px; }

#jsxc_dialog .btn-group.open .dropdown-toggle, #jsxc_webrtc .btn-group.open .dropdown-toggle {
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125); }
  #jsxc_dialog .btn-group.open .dropdown-toggle.btn-link, #jsxc_webrtc .btn-group.open .dropdown-toggle.btn-link {
    box-shadow: none; }

#jsxc_dialog .btn .caret, #jsxc_webrtc .btn .caret {
  margin-left: 0; }

#jsxc_dialog .btn-lg .caret, #jsxc_dialog .btn-group-lg > .btn .caret, #jsxc_dialog #jsxc_webrtc .btn-group-lg > .btn .caret, #jsxc_webrtc .btn-lg .caret, #jsxc_webrtc #jsxc_dialog .btn-group-lg > .btn .caret, #jsxc_webrtc .btn-group-lg > .btn .caret {
  border-width: 5px 5px 0;
  border-bottom-width: 0; }

#jsxc_dialog .dropup .btn-lg .caret, #jsxc_dialog .dropup .btn-group-lg > .btn .caret, #jsxc_dialog .dropup #jsxc_webrtc .btn-group-lg > .btn .caret, #jsxc_webrtc .dropup .btn-lg .caret, #jsxc_webrtc .dropup #jsxc_dialog .btn-group-lg > .btn .caret, #jsxc_webrtc .dropup .btn-group-lg > .btn .caret {
  border-width: 0 5px 5px; }

#jsxc_dialog .btn-group-vertical > .btn,
#jsxc_dialog .btn-group-vertical > .btn-group,
#jsxc_dialog .btn-group-vertical > .btn-group > .btn, #jsxc_webrtc .btn-group-vertical > .btn,
#jsxc_webrtc .btn-group-vertical > .btn-group,
#jsxc_webrtc .btn-group-vertical > .btn-group > .btn {
  display: block;
  float: none;
  width: 100%;
  max-width: 100%; }

#jsxc_dialog .btn-group-vertical > .btn-group:before, #jsxc_dialog .btn-group-vertical > .btn-group:after, #jsxc_webrtc .btn-group-vertical > .btn-group:before, #jsxc_webrtc .btn-group-vertical > .btn-group:after {
  content: " ";
  display: table; }

#jsxc_dialog .btn-group-vertical > .btn-group:after, #jsxc_webrtc .btn-group-vertical > .btn-group:after {
  clear: both; }

#jsxc_dialog .btn-group-vertical > .btn-group > .btn, #jsxc_webrtc .btn-group-vertical > .btn-group > .btn {
  float: none; }

#jsxc_dialog .btn-group-vertical > .btn + .btn,
#jsxc_dialog .btn-group-vertical > .btn + .btn-group,
#jsxc_dialog .btn-group-vertical > .btn-group + .btn,
#jsxc_dialog .btn-group-vertical > .btn-group + .btn-group, #jsxc_webrtc .btn-group-vertical > .btn + .btn,
#jsxc_webrtc .btn-group-vertical > .btn + .btn-group,
#jsxc_webrtc .btn-group-vertical > .btn-group + .btn,
#jsxc_webrtc .btn-group-vertical > .btn-group + .btn-group {
  margin-top: -1px;
  margin-left: 0; }

#jsxc_dialog .btn-group-vertical > .btn:not(:first-child):not(:last-child), #jsxc_webrtc .btn-group-vertical > .btn:not(:first-child):not(:last-child) {
  border-radius: 0; }

#jsxc_dialog .btn-group-vertical > .btn:first-child:not(:last-child), #jsxc_webrtc .btn-group-vertical > .btn:first-child:not(:last-child) {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0; }

#jsxc_dialog .btn-group-vertical > .btn:last-child:not(:first-child), #jsxc_webrtc .btn-group-vertical > .btn:last-child:not(:first-child) {
  border-bottom-left-radius: 4px;
  border-top-right-radius: 0;
  border-top-left-radius: 0; }

#jsxc_dialog .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn, #jsxc_webrtc .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0; }

#jsxc_dialog .btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child,
#jsxc_dialog .btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle, #jsxc_webrtc .btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child,
#jsxc_webrtc .btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0; }

#jsxc_dialog .btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child, #jsxc_webrtc .btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child {
  border-top-right-radius: 0;
  border-top-left-radius: 0; }

#jsxc_dialog .btn-group-justified, #jsxc_webrtc .btn-group-justified {
  display: table;
  width: 100%;
  table-layout: fixed;
  border-collapse: separate; }
  #jsxc_dialog .btn-group-justified > .btn,
  #jsxc_dialog .btn-group-justified > .btn-group, #jsxc_webrtc .btn-group-justified > .btn,
  #jsxc_webrtc .btn-group-justified > .btn-group {
    float: none;
    display: table-cell;
    width: 1%; }
  #jsxc_dialog .btn-group-justified > .btn-group .btn, #jsxc_webrtc .btn-group-justified > .btn-group .btn {
    width: 100%; }
  #jsxc_dialog .btn-group-justified > .btn-group .dropdown-menu, #jsxc_webrtc .btn-group-justified > .btn-group .dropdown-menu {
    left: auto; }

#jsxc_dialog [data-toggle="buttons"] > .btn input[type="radio"],
#jsxc_dialog [data-toggle="buttons"] > .btn input[type="checkbox"],
#jsxc_dialog [data-toggle="buttons"] > .btn-group > .btn input[type="radio"],
#jsxc_dialog [data-toggle="buttons"] > .btn-group > .btn input[type="checkbox"], #jsxc_webrtc [data-toggle="buttons"] > .btn input[type="radio"],
#jsxc_webrtc [data-toggle="buttons"] > .btn input[type="checkbox"],
#jsxc_webrtc [data-toggle="buttons"] > .btn-group > .btn input[type="radio"],
#jsxc_webrtc [data-toggle="buttons"] > .btn-group > .btn input[type="checkbox"] {
  position: absolute;
  clip: rect(0, 0, 0, 0);
  pointer-events: none; }

#jsxc_dialog fieldset, #jsxc_webrtc fieldset {
  padding: 0;
  margin: 0;
  border: 0;
  min-width: 0; }

#jsxc_dialog legend, #jsxc_webrtc legend {
  display: block;
  width: 100%;
  padding: 0;
  margin-bottom: 20px;
  font-size: 21px;
  line-height: inherit;
  color: #333333;
  border: 0;
  border-bottom: 1px solid #e5e5e5; }

#jsxc_dialog label, #jsxc_webrtc label {
  display: inline-block;
  max-width: 100%;
  margin-bottom: 5px;
  font-weight: bold; }

#jsxc_dialog input[type="search"], #jsxc_webrtc input[type="search"] {
  box-sizing: border-box; }

#jsxc_dialog input[type="radio"],
#jsxc_dialog input[type="checkbox"], #jsxc_webrtc input[type="radio"],
#jsxc_webrtc input[type="checkbox"] {
  margin: 4px 0 0;
  margin-top: 1px \9;
  line-height: normal; }

#jsxc_dialog input[type="file"], #jsxc_webrtc input[type="file"] {
  display: block; }

#jsxc_dialog input[type="range"], #jsxc_webrtc input[type="range"] {
  display: block;
  width: 100%; }

#jsxc_dialog select[multiple],
#jsxc_dialog select[size], #jsxc_webrtc select[multiple],
#jsxc_webrtc select[size] {
  height: auto; }

#jsxc_dialog input[type="file"]:focus,
#jsxc_dialog input[type="radio"]:focus,
#jsxc_dialog input[type="checkbox"]:focus, #jsxc_webrtc input[type="file"]:focus,
#jsxc_webrtc input[type="radio"]:focus,
#jsxc_webrtc input[type="checkbox"]:focus {
  outline: thin dotted;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px; }

#jsxc_dialog output, #jsxc_webrtc output {
  display: block;
  padding-top: 7px;
  font-size: 14px;
  line-height: 1.428571429;
  color: #555555; }

#jsxc_dialog .form-control, #jsxc_webrtc .form-control {
  display: block;
  width: 100%;
  height: 34px;
  padding: 6px 12px;
  font-size: 14px;
  line-height: 1.428571429;
  color: #555555;
  background-color: #fff;
  background-image: none;
  border: 1px solid #ccc;
  border-radius: 4px;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -webkit-transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
  transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s; }
  #jsxc_dialog .form-control:focus, #jsxc_webrtc .form-control:focus {
    border-color: #66afe9;
    outline: 0;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6); }
  #jsxc_dialog .form-control::-moz-placeholder, #jsxc_webrtc .form-control::-moz-placeholder {
    color: #999;
    opacity: 1; }
  #jsxc_dialog .form-control:-ms-input-placeholder, #jsxc_webrtc .form-control:-ms-input-placeholder {
    color: #999; }
  #jsxc_dialog .form-control::-webkit-input-placeholder, #jsxc_webrtc .form-control::-webkit-input-placeholder {
    color: #999; }
  #jsxc_dialog .form-control[disabled], #jsxc_dialog .form-control[readonly],
  fieldset[disabled] #jsxc_dialog .form-control, #jsxc_webrtc .form-control[disabled], #jsxc_webrtc .form-control[readonly],
  fieldset[disabled] #jsxc_webrtc .form-control {
    background-color: #eeeeee;
    opacity: 1; }
  #jsxc_dialog .form-control[disabled],
  fieldset[disabled] #jsxc_dialog .form-control, #jsxc_webrtc .form-control[disabled],
  fieldset[disabled] #jsxc_webrtc .form-control {
    cursor: not-allowed; }

#jsxc_dialog textarea.form-control, #jsxc_webrtc textarea.form-control {
  height: auto; }

#jsxc_dialog input[type="search"], #jsxc_webrtc input[type="search"] {
  -webkit-appearance: none; }

@media screen and (-webkit-min-device-pixel-ratio: 0) {
  #jsxc_dialog input[type="date"],
  #jsxc_dialog input[type="time"],
  #jsxc_dialog input[type="datetime-local"],
  #jsxc_dialog input[type="month"], #jsxc_webrtc input[type="date"],
  #jsxc_webrtc input[type="time"],
  #jsxc_webrtc input[type="datetime-local"],
  #jsxc_webrtc input[type="month"] {
    line-height: 34px; }
    #jsxc_dialog input[type="date"].input-sm,
    .input-group-sm #jsxc_dialog input[type="date"],
    #jsxc_dialog input[type="time"].input-sm,
    .input-group-sm
    #jsxc_dialog input[type="time"],
    #jsxc_dialog input[type="datetime-local"].input-sm,
    .input-group-sm
    #jsxc_dialog input[type="datetime-local"],
    #jsxc_dialog input[type="month"].input-sm,
    .input-group-sm
    #jsxc_dialog input[type="month"], #jsxc_webrtc input[type="date"].input-sm,
    .input-group-sm #jsxc_webrtc input[type="date"],
    #jsxc_webrtc input[type="time"].input-sm,
    .input-group-sm
    #jsxc_webrtc input[type="time"],
    #jsxc_webrtc input[type="datetime-local"].input-sm,
    .input-group-sm
    #jsxc_webrtc input[type="datetime-local"],
    #jsxc_webrtc input[type="month"].input-sm,
    .input-group-sm
    #jsxc_webrtc input[type="month"] {
      line-height: 30px; }
    #jsxc_dialog input[type="date"].input-lg,
    .input-group-lg #jsxc_dialog input[type="date"],
    #jsxc_dialog input[type="time"].input-lg,
    .input-group-lg
    #jsxc_dialog input[type="time"],
    #jsxc_dialog input[type="datetime-local"].input-lg,
    .input-group-lg
    #jsxc_dialog input[type="datetime-local"],
    #jsxc_dialog input[type="month"].input-lg,
    .input-group-lg
    #jsxc_dialog input[type="month"], #jsxc_webrtc input[type="date"].input-lg,
    .input-group-lg #jsxc_webrtc input[type="date"],
    #jsxc_webrtc input[type="time"].input-lg,
    .input-group-lg
    #jsxc_webrtc input[type="time"],
    #jsxc_webrtc input[type="datetime-local"].input-lg,
    .input-group-lg
    #jsxc_webrtc input[type="datetime-local"],
    #jsxc_webrtc input[type="month"].input-lg,
    .input-group-lg
    #jsxc_webrtc input[type="month"] {
      line-height: 46px; } }

#jsxc_dialog .form-group, #jsxc_webrtc .form-group {
  margin-bottom: 15px; }

#jsxc_dialog .radio,
#jsxc_dialog .checkbox, #jsxc_webrtc .radio,
#jsxc_webrtc .checkbox {
  position: relative;
  display: block;
  margin-top: 10px;
  margin-bottom: 10px; }
  #jsxc_dialog .radio label,
  #jsxc_dialog .checkbox label, #jsxc_webrtc .radio label,
  #jsxc_webrtc .checkbox label {
    min-height: 20px;
    padding-left: 20px;
    margin-bottom: 0;
    font-weight: normal;
    cursor: pointer; }

#jsxc_dialog .radio input[type="radio"],
#jsxc_dialog .radio-inline input[type="radio"],
#jsxc_dialog .checkbox input[type="checkbox"],
#jsxc_dialog .checkbox-inline input[type="checkbox"], #jsxc_webrtc .radio input[type="radio"],
#jsxc_webrtc .radio-inline input[type="radio"],
#jsxc_webrtc .checkbox input[type="checkbox"],
#jsxc_webrtc .checkbox-inline input[type="checkbox"] {
  position: absolute;
  margin-left: -20px;
  margin-top: 4px \9; }

#jsxc_dialog .radio + .radio,
#jsxc_dialog .checkbox + .checkbox, #jsxc_webrtc .radio + .radio,
#jsxc_webrtc .checkbox + .checkbox {
  margin-top: -5px; }

#jsxc_dialog .radio-inline,
#jsxc_dialog .checkbox-inline, #jsxc_webrtc .radio-inline,
#jsxc_webrtc .checkbox-inline {
  position: relative;
  display: inline-block;
  padding-left: 20px;
  margin-bottom: 0;
  vertical-align: middle;
  font-weight: normal;
  cursor: pointer; }

#jsxc_dialog .radio-inline + .radio-inline,
#jsxc_dialog .checkbox-inline + .checkbox-inline, #jsxc_webrtc .radio-inline + .radio-inline,
#jsxc_webrtc .checkbox-inline + .checkbox-inline {
  margin-top: 0;
  margin-left: 10px; }

#jsxc_dialog input[type="radio"][disabled], #jsxc_dialog input[type="radio"].disabled,
fieldset[disabled] #jsxc_dialog input[type="radio"],
#jsxc_dialog input[type="checkbox"][disabled],
#jsxc_dialog input[type="checkbox"].disabled,
fieldset[disabled]
#jsxc_dialog input[type="checkbox"], #jsxc_webrtc input[type="radio"][disabled], #jsxc_webrtc input[type="radio"].disabled,
fieldset[disabled] #jsxc_webrtc input[type="radio"],
#jsxc_webrtc input[type="checkbox"][disabled],
#jsxc_webrtc input[type="checkbox"].disabled,
fieldset[disabled]
#jsxc_webrtc input[type="checkbox"] {
  cursor: not-allowed; }

#jsxc_dialog .radio-inline.disabled,
fieldset[disabled] #jsxc_dialog .radio-inline,
#jsxc_dialog .checkbox-inline.disabled,
fieldset[disabled]
#jsxc_dialog .checkbox-inline, #jsxc_webrtc .radio-inline.disabled,
fieldset[disabled] #jsxc_webrtc .radio-inline,
#jsxc_webrtc .checkbox-inline.disabled,
fieldset[disabled]
#jsxc_webrtc .checkbox-inline {
  cursor: not-allowed; }

#jsxc_dialog .radio.disabled label,
fieldset[disabled] #jsxc_dialog .radio label,
#jsxc_dialog .checkbox.disabled label,
fieldset[disabled]
#jsxc_dialog .checkbox label, #jsxc_webrtc .radio.disabled label,
fieldset[disabled] #jsxc_webrtc .radio label,
#jsxc_webrtc .checkbox.disabled label,
fieldset[disabled]
#jsxc_webrtc .checkbox label {
  cursor: not-allowed; }

#jsxc_dialog .form-control-static, #jsxc_webrtc .form-control-static {
  padding-top: 7px;
  padding-bottom: 7px;
  margin-bottom: 0;
  min-height: 34px; }
  #jsxc_dialog .form-control-static.input-lg, #jsxc_dialog .form-control-static.input-sm, #jsxc_webrtc .form-control-static.input-lg, #jsxc_webrtc .form-control-static.input-sm {
    padding-left: 0;
    padding-right: 0; }

#jsxc_dialog .input-sm, #jsxc_webrtc .input-sm {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px; }

#jsxc_dialog select.input-sm, #jsxc_webrtc select.input-sm {
  height: 30px;
  line-height: 30px; }

#jsxc_dialog textarea.input-sm,
#jsxc_dialog select[multiple].input-sm, #jsxc_webrtc textarea.input-sm,
#jsxc_webrtc select[multiple].input-sm {
  height: auto; }

#jsxc_dialog .form-group-sm .form-control, #jsxc_webrtc .form-group-sm .form-control {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px; }

#jsxc_dialog .form-group-sm select.form-control, #jsxc_webrtc .form-group-sm select.form-control {
  height: 30px;
  line-height: 30px; }

#jsxc_dialog .form-group-sm textarea.form-control,
#jsxc_dialog .form-group-sm select[multiple].form-control, #jsxc_webrtc .form-group-sm textarea.form-control,
#jsxc_webrtc .form-group-sm select[multiple].form-control {
  height: auto; }

#jsxc_dialog .form-group-sm .form-control-static, #jsxc_webrtc .form-group-sm .form-control-static {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  min-height: 32px; }

#jsxc_dialog .input-lg, #jsxc_webrtc .input-lg {
  height: 46px;
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.3333333;
  border-radius: 6px; }

#jsxc_dialog select.input-lg, #jsxc_webrtc select.input-lg {
  height: 46px;
  line-height: 46px; }

#jsxc_dialog textarea.input-lg,
#jsxc_dialog select[multiple].input-lg, #jsxc_webrtc textarea.input-lg,
#jsxc_webrtc select[multiple].input-lg {
  height: auto; }

#jsxc_dialog .form-group-lg .form-control, #jsxc_webrtc .form-group-lg .form-control {
  height: 46px;
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.3333333;
  border-radius: 6px; }

#jsxc_dialog .form-group-lg select.form-control, #jsxc_webrtc .form-group-lg select.form-control {
  height: 46px;
  line-height: 46px; }

#jsxc_dialog .form-group-lg textarea.form-control,
#jsxc_dialog .form-group-lg select[multiple].form-control, #jsxc_webrtc .form-group-lg textarea.form-control,
#jsxc_webrtc .form-group-lg select[multiple].form-control {
  height: auto; }

#jsxc_dialog .form-group-lg .form-control-static, #jsxc_webrtc .form-group-lg .form-control-static {
  height: 46px;
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.3333333;
  min-height: 38px; }

#jsxc_dialog .has-feedback, #jsxc_webrtc .has-feedback {
  position: relative; }
  #jsxc_dialog .has-feedback .form-control, #jsxc_webrtc .has-feedback .form-control {
    padding-right: 42.5px; }

#jsxc_dialog .form-control-feedback, #jsxc_webrtc .form-control-feedback {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 2;
  display: block;
  width: 34px;
  height: 34px;
  line-height: 34px;
  text-align: center;
  pointer-events: none; }

#jsxc_dialog .input-lg + .form-control-feedback, #jsxc_webrtc .input-lg + .form-control-feedback {
  width: 46px;
  height: 46px;
  line-height: 46px; }

#jsxc_dialog .input-sm + .form-control-feedback, #jsxc_webrtc .input-sm + .form-control-feedback {
  width: 30px;
  height: 30px;
  line-height: 30px; }

#jsxc_dialog .has-success .help-block,
#jsxc_dialog .has-success .control-label,
#jsxc_dialog .has-success .radio,
#jsxc_dialog .has-success .checkbox,
#jsxc_dialog .has-success .radio-inline,
#jsxc_dialog .has-success .checkbox-inline,
#jsxc_dialog .has-success.radio label,
#jsxc_dialog .has-success.checkbox label,
#jsxc_dialog .has-success.radio-inline label,
#jsxc_dialog .has-success.checkbox-inline label, #jsxc_webrtc .has-success .help-block,
#jsxc_webrtc .has-success .control-label,
#jsxc_webrtc .has-success .radio,
#jsxc_webrtc .has-success .checkbox,
#jsxc_webrtc .has-success .radio-inline,
#jsxc_webrtc .has-success .checkbox-inline,
#jsxc_webrtc .has-success.radio label,
#jsxc_webrtc .has-success.checkbox label,
#jsxc_webrtc .has-success.radio-inline label,
#jsxc_webrtc .has-success.checkbox-inline label {
  color: #3c763d; }

#jsxc_dialog .has-success .form-control, #jsxc_webrtc .has-success .form-control {
  border-color: #3c763d;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }
  #jsxc_dialog .has-success .form-control:focus, #jsxc_webrtc .has-success .form-control:focus {
    border-color: #2b542c;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168; }

#jsxc_dialog .has-success .input-group-addon, #jsxc_webrtc .has-success .input-group-addon {
  color: #3c763d;
  border-color: #3c763d;
  background-color: #dff0d8; }

#jsxc_dialog .has-success .form-control-feedback, #jsxc_webrtc .has-success .form-control-feedback {
  color: #3c763d; }

#jsxc_dialog .has-warning .help-block,
#jsxc_dialog .has-warning .control-label,
#jsxc_dialog .has-warning .radio,
#jsxc_dialog .has-warning .checkbox,
#jsxc_dialog .has-warning .radio-inline,
#jsxc_dialog .has-warning .checkbox-inline,
#jsxc_dialog .has-warning.radio label,
#jsxc_dialog .has-warning.checkbox label,
#jsxc_dialog .has-warning.radio-inline label,
#jsxc_dialog .has-warning.checkbox-inline label, #jsxc_webrtc .has-warning .help-block,
#jsxc_webrtc .has-warning .control-label,
#jsxc_webrtc .has-warning .radio,
#jsxc_webrtc .has-warning .checkbox,
#jsxc_webrtc .has-warning .radio-inline,
#jsxc_webrtc .has-warning .checkbox-inline,
#jsxc_webrtc .has-warning.radio label,
#jsxc_webrtc .has-warning.checkbox label,
#jsxc_webrtc .has-warning.radio-inline label,
#jsxc_webrtc .has-warning.checkbox-inline label {
  color: #8a6d3b; }

#jsxc_dialog .has-warning .form-control, #jsxc_webrtc .has-warning .form-control {
  border-color: #8a6d3b;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }
  #jsxc_dialog .has-warning .form-control:focus, #jsxc_webrtc .has-warning .form-control:focus {
    border-color: #66512c;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b; }

#jsxc_dialog .has-warning .input-group-addon, #jsxc_webrtc .has-warning .input-group-addon {
  color: #8a6d3b;
  border-color: #8a6d3b;
  background-color: #fcf8e3; }

#jsxc_dialog .has-warning .form-control-feedback, #jsxc_webrtc .has-warning .form-control-feedback {
  color: #8a6d3b; }

#jsxc_dialog .has-error .help-block,
#jsxc_dialog .has-error .control-label,
#jsxc_dialog .has-error .radio,
#jsxc_dialog .has-error .checkbox,
#jsxc_dialog .has-error .radio-inline,
#jsxc_dialog .has-error .checkbox-inline,
#jsxc_dialog .has-error.radio label,
#jsxc_dialog .has-error.checkbox label,
#jsxc_dialog .has-error.radio-inline label,
#jsxc_dialog .has-error.checkbox-inline label, #jsxc_webrtc .has-error .help-block,
#jsxc_webrtc .has-error .control-label,
#jsxc_webrtc .has-error .radio,
#jsxc_webrtc .has-error .checkbox,
#jsxc_webrtc .has-error .radio-inline,
#jsxc_webrtc .has-error .checkbox-inline,
#jsxc_webrtc .has-error.radio label,
#jsxc_webrtc .has-error.checkbox label,
#jsxc_webrtc .has-error.radio-inline label,
#jsxc_webrtc .has-error.checkbox-inline label {
  color: #a94442; }

#jsxc_dialog .has-error .form-control, #jsxc_webrtc .has-error .form-control {
  border-color: #a94442;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }
  #jsxc_dialog .has-error .form-control:focus, #jsxc_webrtc .has-error .form-control:focus {
    border-color: #843534;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483; }

#jsxc_dialog .has-error .input-group-addon, #jsxc_webrtc .has-error .input-group-addon {
  color: #a94442;
  border-color: #a94442;
  background-color: #f2dede; }

#jsxc_dialog .has-error .form-control-feedback, #jsxc_webrtc .has-error .form-control-feedback {
  color: #a94442; }

#jsxc_dialog .has-feedback label ~ .form-control-feedback, #jsxc_webrtc .has-feedback label ~ .form-control-feedback {
  top: 25px; }

#jsxc_dialog .has-feedback label.sr-only ~ .form-control-feedback, #jsxc_webrtc .has-feedback label.sr-only ~ .form-control-feedback {
  top: 0; }

#jsxc_dialog .help-block, #jsxc_webrtc .help-block {
  display: block;
  margin-top: 5px;
  margin-bottom: 10px;
  color: #737373; }

@media (min-width: 768px) {
  #jsxc_dialog .form-inline .form-group, #jsxc_webrtc .form-inline .form-group {
    display: inline-block;
    margin-bottom: 0;
    vertical-align: middle; }
  #jsxc_dialog .form-inline .form-control, #jsxc_webrtc .form-inline .form-control {
    display: inline-block;
    width: auto;
    vertical-align: middle; }
  #jsxc_dialog .form-inline .form-control-static, #jsxc_webrtc .form-inline .form-control-static {
    display: inline-block; }
  #jsxc_dialog .form-inline .input-group, #jsxc_webrtc .form-inline .input-group {
    display: inline-table;
    vertical-align: middle; }
    #jsxc_dialog .form-inline .input-group .input-group-addon,
    #jsxc_dialog .form-inline .input-group .input-group-btn,
    #jsxc_dialog .form-inline .input-group .form-control, #jsxc_webrtc .form-inline .input-group .input-group-addon,
    #jsxc_webrtc .form-inline .input-group .input-group-btn,
    #jsxc_webrtc .form-inline .input-group .form-control {
      width: auto; }
  #jsxc_dialog .form-inline .input-group > .form-control, #jsxc_webrtc .form-inline .input-group > .form-control {
    width: 100%; }
  #jsxc_dialog .form-inline .control-label, #jsxc_webrtc .form-inline .control-label {
    margin-bottom: 0;
    vertical-align: middle; }
  #jsxc_dialog .form-inline .radio,
  #jsxc_dialog .form-inline .checkbox, #jsxc_webrtc .form-inline .radio,
  #jsxc_webrtc .form-inline .checkbox {
    display: inline-block;
    margin-top: 0;
    margin-bottom: 0;
    vertical-align: middle; }
    #jsxc_dialog .form-inline .radio label,
    #jsxc_dialog .form-inline .checkbox label, #jsxc_webrtc .form-inline .radio label,
    #jsxc_webrtc .form-inline .checkbox label {
      padding-left: 0; }
  #jsxc_dialog .form-inline .radio input[type="radio"],
  #jsxc_dialog .form-inline .checkbox input[type="checkbox"], #jsxc_webrtc .form-inline .radio input[type="radio"],
  #jsxc_webrtc .form-inline .checkbox input[type="checkbox"] {
    position: relative;
    margin-left: 0; }
  #jsxc_dialog .form-inline .has-feedback .form-control-feedback, #jsxc_webrtc .form-inline .has-feedback .form-control-feedback {
    top: 0; } }

#jsxc_dialog .form-horizontal .radio,
#jsxc_dialog .form-horizontal .checkbox,
#jsxc_dialog .form-horizontal .radio-inline,
#jsxc_dialog .form-horizontal .checkbox-inline, #jsxc_webrtc .form-horizontal .radio,
#jsxc_webrtc .form-horizontal .checkbox,
#jsxc_webrtc .form-horizontal .radio-inline,
#jsxc_webrtc .form-horizontal .checkbox-inline {
  margin-top: 0;
  margin-bottom: 0;
  padding-top: 7px; }

#jsxc_dialog .form-horizontal .radio,
#jsxc_dialog .form-horizontal .checkbox, #jsxc_webrtc .form-horizontal .radio,
#jsxc_webrtc .form-horizontal .checkbox {
  min-height: 27px; }

#jsxc_dialog .form-horizontal .form-group, #jsxc_webrtc .form-horizontal .form-group {
  margin-left: -15px;
  margin-right: -15px; }
  #jsxc_dialog .form-horizontal .form-group:before, #jsxc_dialog .form-horizontal .form-group:after, #jsxc_webrtc .form-horizontal .form-group:before, #jsxc_webrtc .form-horizontal .form-group:after {
    content: " ";
    display: table; }
  #jsxc_dialog .form-horizontal .form-group:after, #jsxc_webrtc .form-horizontal .form-group:after {
    clear: both; }

@media (min-width: 768px) {
  #jsxc_dialog .form-horizontal .control-label, #jsxc_webrtc .form-horizontal .control-label {
    text-align: right;
    margin-bottom: 0;
    padding-top: 7px; } }

#jsxc_dialog .form-horizontal .has-feedback .form-control-feedback, #jsxc_webrtc .form-horizontal .has-feedback .form-control-feedback {
  right: 15px; }

@media (min-width: 768px) {
  #jsxc_dialog .form-horizontal .form-group-lg .control-label, #jsxc_webrtc .form-horizontal .form-group-lg .control-label {
    padding-top: 14.333333px; } }

@media (min-width: 768px) {
  #jsxc_dialog .form-horizontal .form-group-sm .control-label, #jsxc_webrtc .form-horizontal .form-group-sm .control-label {
    padding-top: 6px; } }

#jsxc_dialog .progress, #jsxc_webrtc .progress {
  margin-bottom: 0px; }

.mfp-bg {
  z-index: 9000; }

.mfp-wrap {
  z-index: 9010; }

.mfp-content {
  text-align: center; }

#jsxc_dialog .mfp-close {
  font-size: 23px; }

/* END: bootstrap */
@-webkit-keyframes bounce {
  0% {
    bottom: 0;
    -webkit-animation-timing-function: ease-in;
            animation-timing-function: ease-in; }
  12% {
    bottom: 5px;
    -webkit-animation-timing-function: ease-out;
            animation-timing-function: ease-out; }
  25% {
    bottom: 0;
    -webkit-animation-timing-function: ease-in;
            animation-timing-function: ease-in; }
  37% {
    bottom: 5px;
    -webkit-animation-timing-function: ease-out;
            animation-timing-function: ease-out; }
  50% {
    bottom: 0;
    -webkit-animation-timing-function: ease-in;
            animation-timing-function: ease-in; }
  100% {
    bottom: 0; } }
@keyframes bounce {
  0% {
    bottom: 0;
    -webkit-animation-timing-function: ease-in;
            animation-timing-function: ease-in; }
  12% {
    bottom: 5px;
    -webkit-animation-timing-function: ease-out;
            animation-timing-function: ease-out; }
  25% {
    bottom: 0;
    -webkit-animation-timing-function: ease-in;
            animation-timing-function: ease-in; }
  37% {
    bottom: 5px;
    -webkit-animation-timing-function: ease-out;
            animation-timing-function: ease-out; }
  50% {
    bottom: 0;
    -webkit-animation-timing-function: ease-in;
            animation-timing-function: ease-in; }
  100% {
    bottom: 0; } }

@keyframes bounce {
  0% {
    bottom: 0;
    -webkit-animation-timing-function: ease-in;
            animation-timing-function: ease-in; }
  12% {
    bottom: 5px;
    -webkit-animation-timing-function: ease-out;
            animation-timing-function: ease-out; }
  25% {
    bottom: 0;
    -webkit-animation-timing-function: ease-in;
            animation-timing-function: ease-in; }
  37% {
    bottom: 5px;
    -webkit-animation-timing-function: ease-out;
            animation-timing-function: ease-out; }
  50% {
    bottom: 0;
    -webkit-animation-timing-function: ease-in;
            animation-timing-function: ease-in; }
  100% {
    bottom: 0; } }

#jsxc_buddylist {
  list-style: none;
  padding: 0;
  margin: 0;
  width: 204px;
  z-index: 85; }
  #jsxc_buddylist .jsxc_unreadMsg .jsxc_name {
    padding-right: 0px; }
  #jsxc_buddylist .jsxc_oneway .jsxc_avatar, #jsxc_buddylist .jsxc_oneway .jsxc_caption {
    opacity: 0.7; }
  #jsxc_buddylist .jsxc_right {
    float: right;
    margin-right: 6px; }
    #jsxc_buddylist .jsxc_right div {
      font-weight: bold;
      text-align: center;
      font-size: 13px;
      line-height: 20px;
      color: #fff; }
      #jsxc_buddylist .jsxc_right div:hover {
        opacity: 1.0; }
  #jsxc_buddylist .jsxc_more {
    margin-right: 6px;
    z-index: 10;
    position: relative; }
  #jsxc_buddylist .jsxc_options {
    height: 20px;
    float: left;
    border-radius: 2px;
    background-color: rgba(102, 102, 102, 0.5); }
    #jsxc_buddylist .jsxc_options > div {
      height: 20px;
      width: 20px;
      float: left;
      margin-right: 0 1px;
      background-repeat: no-repeat;
      background-position: center center;
      opacity: 0.6;
      cursor: pointer; }
      #jsxc_buddylist .jsxc_options > div:hover {
        opacity: 1; }
  #jsxc_buddylist.jsxc_hideOffline .jsxc_rosteritem[data-status='offline'] {
    display: none; }

.jsxc_online:before, .jsxc_chat:before, .jsxc_away:before, .jsxc_xa:before, .jsxc_dnd:before {
  content: ' ';
  display: block;
  width: 12px;
  height: 12px;
  border-radius: 100%;
  line-height: 12px;
  text-align: center;
  color: #fff;
  z-index: 99;
  background-repeat: no-repeat;
  background-position: center;
  background-size: 100%;
  box-sizing: content-box; }

.jsxc_online:before {
  background-color: green; }

.jsxc_chat:before {
  background-image: url('data:image/svg+xml;base64,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');
  background-color: green; }

.jsxc_away:before {
  background-image: url('data:image/svg+xml;base64,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');
  background-color: #ffa500; }

.jsxc_xa:before {
  background-image: url('data:image/svg+xml;base64,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');
  background-color: #ffa500; }

.jsxc_dnd:before {
  background-image: url('data:image/svg+xml;base64,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');
  background-color: #f00; }

.jsxc_hidden {
  display: none; }

.jsxc_invalid {
  border: 2px solid #f00 !important; }

.jsxc_emoticon {
  display: inline-block;
  width: 19px;
  height: 19px;
  background-size: contain;
  border: 0;
  vertical-align: bottom; }

.jsxc_angel {
  background: url('../img/emotions/angel.png'); }

.jsxc_angry {
  background: url('../img/emotions/angry.png'); }

.jsxc_smile {
  background: url('../img/emotions/smile.png'); }

.jsxc_grin {
  background: url('../img/emotions/grin.png'); }

.jsxc_sad {
  background: url('../img/emotions/sad.png'); }

.jsxc_wink {
  background: url('../img/emotions/wink.png'); }

.jsxc_tonguesmile {
  background: url('../img/emotions/tonguesmile.png'); }

.jsxc_surpised {
  background: url('../img/emotions/surpised.png'); }

.jsxc_kiss {
  background: url('../img/emotions/kiss.png'); }

.jsxc_sunglassess {
  background: url('../img/emotions/sunglassess.png'); }

.jsxc_crysad {
  background: url('../img/emotions/crysad.png'); }

.jsxc_doubt {
  background: url('../img/emotions/doubt.png'); }

.jsxc_zip {
  background: url('../img/emotions/zip.png'); }

.jsxc_thumbsup {
  background: url('../img/emotions/thumbsup.png'); }

.jsxc_thumbsdown {
  background: url('../img/emotions/thumbsdown.png'); }

.jsxc_beer {
  background: url('../img/emotions/beer.png'); }

.jsxc_devil {
  background: url('../img/emotions/devil.png'); }

.jsxc_kissing {
  background: url('../img/emotions/kissing.png'); }

.jsxc_rose {
  background: url('../img/emotions/rose.png'); }

.jsxc_music {
  background: url('../img/emotions/music.png'); }

.jsxc_love {
  background: url('../img/emotions/love.png'); }

.jsxc_tired {
  background: url('../img/emotions/tired.png'); }

.jsxc_surprised {
  background: url('../img/emotions/surprised.png'); }

#jsxc_roster {
  position: fixed;
  top: 39px;
  bottom: 0;
  right: 0;
  width: 205px;
  overflow: visible;
  border-left: 1px solid #e1e1e1;
  display: none;
  /*border-left: 1px solid $roster_border_left;*/
  z-index: 80;
  margin-left: 10px;
  background-color: whitesmoke; }
  #jsxc_roster a {
    cursor: pointer; }
  #jsxc_roster .slimScrollDiv {
    margin-bottom: 30px;
    z-index: 40; }
  #jsxc_roster .jsxc_wait {
    position: absolute;
    top: 0;
    left: 0;
    bottom: 0;
    width: 160px;
    padding: 20px;
    background-color: #fff;
    z-index: 60; }
    #jsxc_roster .jsxc_wait img {
      padding: 5px; }
    #jsxc_roster .jsxc_wait h3 {
      margin-bottom: 5px;
      font-size: 1.13em;
      font-weight: bold; }
  #jsxc_roster input {
    position: absolute;
    margin: 0;
    height: 35px;
    padding: 7px 6px 5px;
    font-size: 13px;
    width: 145px;
    border: 1px solid #ddd;
    box-sizing: border-box;
    background-image: none;
    background-color: #fff;
    border-radius: 3px;
    box-shadow: inner 0 0 5px #666666;
    outline: none; }
  #jsxc_roster p {
    color: #333;
    padding: 10px; }
    #jsxc_roster p a {
      color: #b3b3b3;
      text-decoration: underline; }
  #jsxc_roster .jsxc_avatar {
    position: relative;
    cursor: pointer; }
    #jsxc_roster .jsxc_avatar img {
      cursor: pointer; }
  #jsxc_roster .jsxc_expand input {
    left: 51px;
    width: 137px; }
  #jsxc_roster.jsxc_noConnection .slimScrollDiv {
    display: none; }
  #jsxc_roster.jsxc_noConnection > .jsxc_bottom {
    display: none; }
  #jsxc_roster.jsxc_state_hidden {
    display: block;
    right: -204px;
    -webkit-transition: right 0.5s;
            transition: right 0.5s; }
    #jsxc_roster.jsxc_state_hidden #jsxc_toggleRoster:before {
      -webkit-transform: rotate(0deg);
          -ms-transform: rotate(0deg);
              transform: rotate(0deg); }
  #jsxc_roster.jsxc_state_shown {
    display: block;
    right: 0px;
    -webkit-transition: right 0.5s;
            transition: right 0.5s; }

#jsxc_toggleRoster {
  width: 34px;
  height: 100%;
  position: absolute;
  left: -34px !important;
  top: 0;
  z-index: 110;
  background-color: transparent;
  cursor: pointer; }
  #jsxc_toggleRoster:hover {
    background-color: rgba(153, 153, 153, 0.5); }
  #jsxc_toggleRoster:before {
    content: '';
    position: absolute;
    display: block;
    width: 0;
    top: 50%;
    right: 10px;
    border-style: solid;
    border-width: 6px 4px 6px 0;
    border-color: transparent whitesmoke;
    -webkit-transform: rotate(180deg);
        -ms-transform: rotate(180deg);
            transform: rotate(180deg); }

.jsxc_rosteritem {
  padding: 0;
  margin: 0;
  height: 44px;
  border-bottom: 1px solid transparent;
  cursor: pointer;
  width: 100%;
  position: relative;
  color: #333;
  font-family: Arial, sans-serif;
  line-height: 44px;
  padding-left: 6px;
  padding-top: 4px;
  padding-bottom: 4px;
  box-sizing: border-box; }
  .jsxc_rosteritem:hover {
    background-color: #ddd; }
  .jsxc_rosteritem.jsxc_bookmarked .jsxc_avatar:after {
    content: " ";
    width: 20%;
    height: 30%;
    position: absolute;
    top: 0;
    right: 2px;
    background-size: contain;
    background-repeat: no-repeat;
    background-image: url('data:image/svg+xml;base64,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'); }

.jsxc_caption {
  padding-right: 30px;
  height: 100%;
  line-height: 100%;
  /*padding-top: 4px;*/
  box-sizing: border-box; }
  .jsxc_caption * {
    cursor: pointer; }
  .jsxc_caption .jsxc_name {
    height: 100%;
    line-height: 40px; }
    .jsxc_min .jsxc_caption .jsxc_name {
      height: 50%;
      line-height: 20px; }
    .jsxc_rosteritem .jsxc_caption .jsxc_name {
      height: 50%;
      line-height: 20px; }
  .jsxc_caption .jsxc_lastmsg {
    font-size: 12px;
    display: none;
    text-overflow: ellipsis;
    white-space: nowrap;
    overflow: hidden; }
    .jsxc_min .jsxc_caption .jsxc_lastmsg {
      display: block;
      height: 50%;
      line-height: 17.5px; }
    .jsxc_rosteritem .jsxc_caption .jsxc_lastmsg {
      display: block;
      height: 50%;
      line-height: 17.5px; }
    .jsxc_caption .jsxc_lastmsg .jsxc_text {
      opacity: 0.6; }
    .jsxc_caption .jsxc_lastmsg .jsxc_unread {
      line-height: 100%;
      font-size: 8px;
      color: #fff;
      text-align: center;
      display: none;
      height: 1em;
      width: 1em;
      border-radius: 50%;
      background-color: orange;
      vertical-align: top;
      margin: 0;
      float: none; }
      .jsxc_unreadMsg .jsxc_caption .jsxc_lastmsg .jsxc_unread {
        display: inline-block !important; }
    .jsxc_caption .jsxc_lastmsg .jsxc_emoticon {
      vertical-align: middle; }

#jsxc_roster > .jsxc_bottom {
  position: absolute;
  left: 0;
  bottom: 0;
  width: 100%;
  line-height: 34px;
  background-color: #eeeeee;
  z-index: 50;
  padding-right: 4px; }
  #jsxc_roster > .jsxc_bottom:hover {
    background-color: #ddd; }
  #jsxc_roster > .jsxc_bottom .jsxc_inner {
    width: 100%; }
  #jsxc_roster > .jsxc_bottom ul {
    padding: 0;
    margin: 0;
    width: 100%;
    border-top: 1px solid transparent;
    background-color: #eeeeee;
    margin: 0; }
    #jsxc_roster > .jsxc_bottom ul li:last-child {
      border-bottom: 1px solid transparent; }
  #jsxc_roster > .jsxc_bottom li {
    height: 44px;
    background-color: #eeeeee;
    color: #000;
    cursor: pointer;
    width: 100%;
    padding-left: 44px;
    line-height: 44px;
    text-align: left;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    background-repeat: no-repeat;
    background-position: 15px center;
    background-size: 16px 16px;
    opacity: 0.8; }
    #jsxc_roster > .jsxc_bottom li.jsxc_disabled {
      color: #333333;
      cursor: default; }
    #jsxc_roster > .jsxc_bottom li:hover:not(.jsxc_disabled) {
      color: #000;
      background-color: #ddd; }

#jsxc_roster > .jsxc_bottom > div > span {
  cursor: pointer; }

#jsxc_roster > .jsxc_bottom > div:hover {
  /*color: $roster_bottom_color_hover;*/ }

#jsxc_avatar {
  cursor: default !important; }

#jsxc_presence {
  cursor: pointer;
  padding-left: 2px;
  overflow: hidden; }
  #jsxc_presence > span {
    opacity: 0.8; }
  #jsxc_presence li {
    position: relative; }
    #jsxc_presence li:before {
      /** Presence indicator */
      position: absolute;
      top: 50%;
      left: 10px;
      margin-top: -8px;
      border: 2px solid whitesmoke; }

#jsxc_menu {
  height: 44px;
  width: 44px;
  cursor: pointer;
  float: right;
  text-align: center; }
  #jsxc_menu:hover > span {
    opacity: 1; }
  #jsxc_menu > span {
    opacity: 0.5;
    display: block;
    width: 100%;
    height: 100%;
    background-image: url('data:image/svg+xml;base64,PHN2ZyB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgaGVpZ2h0PSIxNiIgd2lkdGg9IjE2IiB2ZXJzaW9uPSIxLjEiIHhtbG5zOmNjPSJodHRwOi8vY3JlYXRpdmVjb21tb25zLm9yZy9ucyMiIHhtbG5zOmRjPSJodHRwOi8vcHVybC5vcmcvZGMvZWxlbWVudHMvMS4xLyI+CiA8bWV0YWRhdGE+CiAgPHJkZjpSREY+CiAgIDxjYzpXb3JrIHJkZjphYm91dD0iIj4KICAgIDxkYzpmb3JtYXQ+aW1hZ2Uvc3ZnK3htbDwvZGM6Zm9ybWF0PgogICAgPGRjOnR5cGUgcmRmOnJlc291cmNlPSJodHRwOi8vcHVybC5vcmcvZGMvZGNtaXR5cGUvU3RpbGxJbWFnZSIvPgogICAgPGRjOnRpdGxlLz4KICAgPC9jYzpXb3JrPgogIDwvcmRmOlJERj4KIDwvbWV0YWRhdGE+CiA8cGF0aCBkPSJtMiwyLDAsMiwxMiwwLDAtMnptMCw1LDAsMiwxMiwwLDAtMnptMCw1LDAsMiwxMiwwLDAtMnoiLz4KPC9zdmc+Cg==');
    background-repeat: no-repeat;
    background-position: center 10px;
    background-size: 17px; }
  @media (min-width: 768px) {
    #jsxc_menu {
      height: 30px;
      width: 30px; } }

#jsxc_notice {
  height: 30px;
  width: 30px;
  float: right;
  text-align: center;
  line-height: 30px; }
  #jsxc_notice span {
    background-color: #ffa500;
    border-radius: 11px;
    color: #000;
    font-size: 80%;
    padding: 2px;
    position: relative;
    -webkit-animation: bounce 2s 1s infinite;
            animation: bounce 2s 1s infinite; }
  #jsxc_notice > span:empty {
    display: none; }

#jsxc_windowList {
  position: fixed;
  bottom: 0;
  right: 230px;
  left: 0;
  z-index: 50;
  -webkit-transition: right 0.5s;
          transition: right 0.5s; }
  #jsxc_windowList.jsxc_roster_hidden {
    right: 10px; }
  @media (min-width: 768px) {
    #jsxc_windowList {
      clip: rect(-10000px, 10000px, 30px, 30px); } }
  #jsxc_windowList > ul {
    list-style: none;
    padding: 0;
    margin: 0;
    position: absolute;
    bottom: 0;
    right: 0;
    height: 44px;
    overflow: visible;
    white-space: nowrap;
    -webkit-transition: right 0.5s;
            transition: right 0.5s; }
    #jsxc_windowList > ul > li {
      padding: 0;
      margin: 0;
      display: inline-block;
      height: 44px;
      width: 46px;
      position: relative;
      overflow: visible;
      margin-right: 5px;
      cursor: pointer;
      white-space: normal; }
      #jsxc_windowList > ul > li.jsxc_normal {
        -webkit-transition: width 0.2s;
                transition: width 0.2s;
        width: 250px; }
      #jsxc_windowList > ul > li.jsxc_min {
        -webkit-transition: width 0.2s;
                transition: width 0.2s;
        width: 46px !important;
        /* overwrite resizeable width */ }
        @media (min-width: 768px) {
          #jsxc_windowList > ul > li.jsxc_min {
            width: 200px !important; } }
        #jsxc_windowList > ul > li.jsxc_min .jsxc_emoticons {
          display: none; }
        #jsxc_windowList > ul > li.jsxc_min .jsxc_tools {
          display: none; }

#jsxc_windowListSB {
  position: fixed;
  left: 0;
  bottom: 0;
  width: 30px;
  height: 30px; }
  @media (max-width: 768px) {
    #jsxc_windowListSB {
      display: none; } }
  #jsxc_windowListSB > div {
    box-sizing: border-box;
    width: 14px;
    height: 100%;
    background-color: #cccccc;
    color: gray;
    text-align: center;
    line-height: 30px;
    float: left;
    cursor: pointer;
    -webkit-user-select: none;
       -moz-user-select: none;
        -ms-user-select: none;
            user-select: none; }
    #jsxc_windowListSB > div:hover {
      background-color: #b3b3b3; }
  #jsxc_windowListSB > .jsxc_disabled {
    background-color: #e6e6e6 !important;
    color: #cccccc;
    cursor: default !important;
    display: none; }

.jsxc_bar {
  background-color: #1d2d44;
  cursor: pointer;
  height: 44px;
  line-height: 26px;
  padding: 2px;
  color: #bbb;
  width: 100%;
  box-sizing: border-box;
  position: relative; }
  .jsxc_normal .jsxc_bar:hover {
    color: #fff; }
  .jsxc_normal .jsxc_bar .jsxc_tools:hover {
    color: #000; }
  .jsxc_min .jsxc_bar {
    background-color: #eee;
    color: #000; }

.jsxc_window {
  position: absolute;
  bottom: -284px;
  top: auto;
  left: 0;
  right: 0;
  height: auto;
  background-color: whitesmoke;
  z-index: 80;
  cursor: default;
  border: 1px solid #e1e1e1;
  border-bottom: 0; }
  .jsxc_min .jsxc_window {
    -webkit-transition: bottom 0.2s;
            transition: bottom 0.2s; }
  .jsxc_normal .jsxc_window {
    -webkit-transition: bottom 0.2s;
            transition: bottom 0.2s; }
  .jsxc_showOverlay .jsxc_window .jsxc_overlay {
    display: block !important; }
  .jsxc_window .jsxc_emoticons {
    height: 44px;
    width: 44px;
    position: absolute;
    bottom: 0;
    left: 0;
    cursor: pointer; }
    .jsxc_window .jsxc_emoticons:after {
      content: ' ';
      background-image: url('data:image/svg+xml;base64,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');
      background-position: center center;
      background-repeat: no-repeat;
      background-size: 30px 30px;
      opacity: 0.3;
      position: absolute;
      top: 0;
      left: 0;
      right: 0;
      bottom: 0; }
    .jsxc_window .jsxc_emoticons .jsxc_inner {
      left: 5px; }
    .jsxc_window .jsxc_emoticons ul {
      width: 210px;
      margin-bottom: 8px;
      background-color: rgba(51, 51, 51, 0.8);
      border-radius: 3px;
      z-index: 200;
      list-style-type: none;
      padding: 3px;
      position: relative; }
      .jsxc_window .jsxc_emoticons ul:after {
        content: '';
        position: absolute;
        border-left: 8px solid transparent;
        border-right: 8px solid transparent;
        border-top: 8px solid rgba(51, 51, 51, 0.8);
        display: block;
        width: 0;
        z-index: 1;
        left: 7px;
        top: 100%; }
    .jsxc_window .jsxc_emoticons li div {
      float: left;
      cursor: pointer;
      border-radius: 3px;
      background-size: 30px 30px;
      width: 30px;
      height: 30px; }
      .jsxc_window .jsxc_emoticons li div:hover {
        background-color: rgba(255, 255, 255, 0.8); }
    .jsxc_window .jsxc_emoticons:hover:after {
      opacity: 0.5; }
  .jsxc_window .jsxc_fade {
    position: relative; }
    .jsxc_window .jsxc_fade .jsxc_overlay {
      display: none;
      background-color: rgba(0, 0, 0, 0.5);
      position: absolute;
      top: 0;
      right: 0;
      bottom: 0;
      left: 0;
      z-index: 100;
      overflow-y: scroll; }
      .jsxc_window .jsxc_fade .jsxc_overlay > div {
        background-color: #fff;
        margin: 30px 10px;
        padding: 5px;
        border-radius: 3px;
        text-align: center;
        position: relative; }
        .jsxc_window .jsxc_fade .jsxc_overlay > div .jsxc_close {
          position: absolute;
          top: 0;
          right: 0;
          height: 44px;
          width: 44px; }
          .jsxc_window .jsxc_fade .jsxc_overlay > div .jsxc_close:after {
            content: '×';
            position: absolute;
            top: 4px;
            right: 4px;
            font-size: 20px;
            font-family: Arial, sans-serif;
            cursor: pointer;
            color: #000;
            opacity: 0.4; }
          .jsxc_window .jsxc_fade .jsxc_overlay > div .jsxc_close:hover:after {
            opacity: 1; }
          @media (min-width: 768px) {
            .jsxc_window .jsxc_fade .jsxc_overlay > div .jsxc_close {
              width: 30px;
              height: 30px; } }
        .jsxc_window .jsxc_fade .jsxc_overlay > div .jsxc_body {
          margin-top: 20px; }
        .jsxc_window .jsxc_fade .jsxc_overlay > div p {
          margin-bottom: 10px; }
        .jsxc_window .jsxc_fade .jsxc_overlay > div li {
          white-space: nowrap;
          overflow: hidden;
          text-overflow: ellipsis; }
        .jsxc_window .jsxc_fade .jsxc_overlay > div a:hover {
          text-decoration: underline; }
  .jsxc_window .jsxc_avatar {
    margin-top: 1px; }
  .jsxc_window .jsxc_textarea {
    width: 100%;
    overflow: hidden;
    padding: 3px; }
  .jsxc_window .slimScrollDiv {
    margin: 0 0 6px 0;
    left: auto !important;
    top: auto !important; }
  .jsxc_window input.jsxc_textinput {
    width: 100%;
    height: 44px;
    margin: 0;
    padding: 3px;
    padding-left: 40px;
    padding-right: 40px;
    outline: none;
    border-radius: 0;
    box-sizing: border-box;
    border: 0; }
  .jsxc_window input::-webkit-input-placeholder {
    color: #000;
    opacity: 0.3; }
  .jsxc_window input::-moz-placeholder {
    color: #000;
    opacity: 0.3; }
  .jsxc_window input:-ms-input-placeholder {
    color: #000;
    opacity: 0.3; }
  .jsxc_window input::placeholder {
    color: #000;
    opacity: 0.3; }
  .jsxc_window .jsxc_tools {
    float: right; }
    .jsxc_window .jsxc_tools > .jsxc_disabled {
      opacity: 0.3;
      cursor: default !important; }
    .jsxc_window .jsxc_tools > div {
      width: 25px;
      height: 40px;
      display: block;
      float: left;
      color: #fff;
      opacity: 0.4;
      font-family: Arial, sans-serif;
      line-height: 40px;
      cursor: pointer;
      text-align: center; }
      .jsxc_window .jsxc_tools > div.jsxc_settings {
        opacity: 1.0; }
  .jsxc_window .jsxc_close {
    font-size: 20px; }
    .jsxc_window .jsxc_close:hover {
      color: #fff;
      opacity: 1.0; }
  .jsxc_window .jsxc_more {
    background-image: url('data:image/svg+xml;base64,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');
    opacity: 0.4; }
  .jsxc_window .ui-resizable-w {
    left: 0; }
  .jsxc_window .ui-resizable-nw {
    top: 0;
    left: 0;
    width: 15px;
    height: 15px;
    z-index: 95 !important;
    background-image: url('data:image/svg+xml;base64,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'); }
  .jsxc_window .ui-resizable-n {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    height: 15px;
    z-index: 100; }

.jsxc_chatmessage {
  margin: 3px;
  padding: 4px;
  word-wrap: break-word;
  background-color: #fff;
  position: relative;
  outline: none;
  clear: both; }
  .jsxc_chatmessage a {
    color: #00f;
    text-decoration: underline;
    display: inline-block; }
  .jsxc_chatmessage img {
    max-width: 100%; }
  .jsxc_chatmessage .jsxc_avatar {
    display: none; }
  .jsxc_chatmessage .jsxc_attachment {
    border-radius: 3px;
    background-color: #fff;
    padding: 3px;
    padding-left: 30px;
    min-height: 30px;
    margin-bottom: 5px;
    background-position: 3px center;
    background-size: 25px 25px;
    background-repeat: no-repeat;
    background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+CjxzdmcgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGhlaWdodD0iMTYiIHdpZHRoPSIxNiIgdmVyc2lvbj0iMS4wIiB4bWxuczpjYz0iaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbnMjIiB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iPgogPHBhdGggc3R5bGU9ImNvbG9yOiMwMDAwMDA7YmxvY2stcHJvZ3Jlc3Npb246dGI7dGV4dC10cmFuc2Zvcm06bm9uZTt0ZXh0LWluZGVudDowIiBkPSJtMi4zNTAxIDEuMDAxNGMtMC4xOTc1MSAwLjAzODItMC4zNTM1MSAwLjIzMzMxLTAuMzUwMDEgMC40Mzc0MnYxMy4xMjNjMC4wMDAwMDUgMC4yMjkwNSAwLjIwNTIzIDAuNDM3NDUgMC40MzA3OSAwLjQzNzQ2bDExLjEzOSAwLjAwMWMwLjIyNTU2LTAuMDAwMDA2IDAuNDMwNzgtMC4yMDg0MSAwLjQzMDc5LTAuNDM3NDZ2LTEwLjE0M2MtMC4wMDQtMC4wNjY4NC0wLjAyMi0wLjEzMjg0LTAuMDU0LTAuMTkxMzVsLTMuMzEyMS0zLjE5ODljLTAuMDQzLTAuMDE2NC0wLjA4OC0wLjAyNTYtMC4xMzQtMC4wMjc0bC04LjA2OTktMC4wMDFjLTAuMDI2ODQtMC4wMDI2LTAuMDUzOTMtMC4wMDI2LTAuMDgwNzcgMHoiIGZpbGw9IiM5Njk2OTYiLz4KPC9zdmc+Cg=='); }
    .jsxc_chatmessage .jsxc_attachment img {
      border-radius: 3px; }
    .jsxc_chatmessage .jsxc_attachment.jsxc_image {
      line-height: 0px;
      padding: 0;
      background-image: url(); }
    .jsxc_chatmessage .jsxc_attachment.jsxc_application {
      background-image: url('data:image/svg+xml;base64,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'); }
    .jsxc_chatmessage .jsxc_attachment.jsxc_application-pdf {
      background-image: url('data:image/svg+xml;base64,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'); }
    .jsxc_chatmessage .jsxc_attachment.jsxc_audio {
      background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+CjxzdmcgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGhlaWdodD0iMTYiIHdpZHRoPSIxNiIgdmVyc2lvbj0iMS4wIiB4bWxuczpjYz0iaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbnMjIiB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iPgogPHBhdGggZD0ibTEyLjgwNSAxLjAwMTFjLTIuMiAwLjM1NDUtNS4xNDQ1IDAuNzE5NC03LjMzODMgMS4wOTM3LTAuNTgxIDAuMjgzNS0wLjQ1MDMgMS4wMTMzLTAuNDc2MSAxLjU0Mjl2Ny4wODk1Yy0xLjIyNDMtMC4yMzAxNy0yLjcxNzMgMC43ODE0Mi0yLjc4MiAyLjM4MzEtMC4xMDU3IDAuOTk3MjEgMC43Nzg1OSAxLjg2NTIgMS43NDAyIDEuODg4NSAxLjcyMTcgMC4wNDE3OSAyLjg5OTItMS4xMDA1IDIuOTE3OS0yLjU0NS0wLjAxODc2LTIuNDI2MSAwLjAwNTYtNC44NTMzIDAtNy4yNzk1IDAuMjY2NTQtMC4wMTk3NCA0LjMwMzYtMC43OTAwNiA0LjY2NjctMC44NDEzNHY1LjQ1MmMtMS4wNy0wLjI1NjEtMi40Mzc0IDAuNDQ3Mi0yLjc3NjYgMS44ODMyLTAuMTQzMTQgMC44MDQ4OSAwLjEyNzQgMS44MTUyIDAuOTQ0MTEgMi4xNTYgMS41OTQzIDAuNzMyNjEgMy43ODMtMC43NTEzNyAzLjY5NC0yLjQ5My0wLjAyNDczLTMuMjM1IDAuMDIwMjUtNi40NzE3IDAtOS43MDctMC4wNDItMC4zMDQyMi0wLjI0ODI3LTAuNjQ0NzQtMC41OTAzMy0wLjYyMjgxeiIgZmlsbD0iIzk2OTY5NiIvPgo8L3N2Zz4K'); }
    .jsxc_chatmessage .jsxc_attachment.jsxc_video {
      background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+CjxzdmcgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGhlaWdodD0iMTYiIHdpZHRoPSIxNiIgdmVyc2lvbj0iMS4wIiB4bWxuczpjYz0iaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbnMjIiB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iPgogPHBhdGggc3R5bGU9ImNvbG9yOiMwMDAwMDA7YmxvY2stcHJvZ3Jlc3Npb246dGI7dGV4dC10cmFuc2Zvcm06bm9uZTt0ZXh0LWluZGVudDowIiBkPSJtMS4zNDM4IDJjLTAuMTk3NSAwLjAzODItMC4zNDczNiAwLjIzMzQtMC4zNDM4IDAuNDM3NXYxMS4xMjVjMCAwLjIyOSAwLjIxMiAwLjQzOCAwLjQzNzUgMC40MzhoMTMuMTI1YzAuMjI1NTUtMC4wMDAwMDYgMC40Mzc1LTAuMjA4NDYgMC40Mzc1LTAuNDM3NXYtMTAuOTUzYzAtMC4zMzYyLTAuMjY1LTAuNjExLTAuNTE2LTAuNjA5em0wLjY1NjIgMWgxMnYxMGgtMTJ6bTMgMnY2bDYtM3oiIGZpbGw9IiM5Njk2OTYiLz4KPC9zdmc+Cg=='); }
    .jsxc_chatmessage .jsxc_attachment.jsxc_text {
      background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+CjxzdmcgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGhlaWdodD0iMTYiIHdpZHRoPSIxNiIgdmVyc2lvbj0iMS4wIiB4bWxuczpjYz0iaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbnMjIiB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iPgogPHBhdGggc3R5bGU9ImNvbG9yOiMwMDAwMDA7YmxvY2stcHJvZ3Jlc3Npb246dGI7dGV4dC10cmFuc2Zvcm06bm9uZTt0ZXh0LWluZGVudDowIiBkPSJtMi4zNDk2IDEuMDAyYy0wLjE5NzUgMC4wMzgyLTAuMzUzMSAwLjIzMzMtMC4zNDk2IDAuNDM3NXYxMy4xMjJjMCAwLjIzIDAuMjA2MSAwLjQzOCAwLjQzMTYgMC40MzhoMTEuMTM4YzAuMjI2IDAgMC40MzItMC4yMDggMC40MzItMC40Mzh2LTEwLjE0MmMtMC4wMDQtMC4wNjY5LTAuMDIzLTAuMTMzLTAuMDU1LTAuMTkxNWwtMy4zMTItMy4xOTkyYy0wLjA0My0wLjAxNjQtMC4wODktMC4wMjU1LTAuMTM1LTAuMDI3M2gtOC4wNjg0Yy0wLjAyNjgtMC4wMDI2NS0wLjA1NTItMC4wMDI2NS0wLjA4MiAwem0xLjY1MDQgMS45OThoNnYxaC02di0xem0wIDNoNXYxaC01di0xem0wIDNoOHYxaC04di0xem0wIDNoNHYxaC00di0xeiIgZmlsbD0iIzk2OTY5NiIvPgo8L3N2Zz4K'); }

.jsxc_timestamp {
  font-size: 8px;
  color: #999999;
  line-height: 8px;
  overflow: hidden;
  white-space: nowrap;
  max-width: 100%;
  text-overflow: ellipsis;
  clear: both; }

.jsxc_encrypted.jsxc_received.jsxc_out .jsxc_timestamp {
  margin-right: 1px; }

.jsxc_encrypted .jsxc_timestamp:after {
  content: " ";
  display: inline-block;
  width: 10px;
  height: 8px;
  margin-left: 2px;
  background-image: url('data:image/svg+xml;base64,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');
  background-size: contain;
  background-repeat: no-repeat; }

.jsxc_in {
  float: left;
  position: relative;
  max-width: 76%;
  margin-left: 10px;
  border-radius: 3px;
  background-color: #DBEDFF; }
  .jsxc_in:after {
    content: ' ';
    position: absolute;
    border-style: solid;
    border-width: 5px 6px 5px 0;
    border-color: transparent #DBEDFF;
    display: block;
    width: 0;
    z-index: 1;
    left: -6px;
    bottom: 10px; }
  .jsxc_in .jsxc_timestamp {
    float: left; }

.jsxc_out {
  float: right;
  position: relative;
  max-width: 76%;
  margin-right: 10px;
  padding-right: 10px;
  border-radius: 3px;
  background-color: #e6ffd1; }
  .jsxc_out:after {
    content: ' ';
    position: absolute;
    border-style: solid;
    border-width: 5px 0 5px 6px;
    border-color: transparent #e6ffd1;
    display: block;
    width: 0;
    z-index: 1;
    right: -6px;
    bottom: 10px; }
  .jsxc_out.jsxc_received:before {
    content: '✓';
    position: absolute;
    bottom: 2px;
    right: 2px;
    font-size: 12px;
    line-height: 12px;
    color: #008000; }
  .jsxc_out.jsxc_received .jsxc_timestamp {
    margin-right: 4px; }
  .jsxc_out .jsxc_timestamp {
    float: right; }

.jsxc_sys {
  width: auto;
  max-width: none;
  padding-right: 4px;
  box-sizing: border-box;
  margin-right: 3px;
  border-radius: 3px; }

div.jsxc_settings {
  position: relative; }
  div.jsxc_settings .jsxc_inner {
    left: auto;
    top: 100%;
    right: -6px; }

div.jsxc_transfer {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+CjxzdmcKICAgeG1sbnM6ZGM9Imh0dHA6Ly9wdXJsLm9yZy9kYy9lbGVtZW50cy8xLjEvIgogICB4bWxuczpjYz0iaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbnMjIgogICB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgdmlld0JveD0iMCAwIDE1IDE1IgogICBpZD0ic3ZnMzA0MSIKICAgaGVpZ2h0PSIxNSIKICAgd2lkdGg9IjE1IgogICB2ZXJzaW9uPSIxLjEiPgogIDxtZXRhZGF0YQogICAgIGlkPSJtZXRhZGF0YTMwNDciPgogICAgPHJkZjpSREY+CiAgICAgIDxjYzpXb3JrCiAgICAgICAgIHJkZjphYm91dD0iIj4KICAgICAgICA8ZGM6Zm9ybWF0PmltYWdlL3N2Zyt4bWw8L2RjOmZvcm1hdD4KICAgICAgICA8ZGM6dHlwZQogICAgICAgICAgIHJkZjpyZXNvdXJjZT0iaHR0cDovL3B1cmwub3JnL2RjL2RjbWl0eXBlL1N0aWxsSW1hZ2UiIC8+CiAgICAgICAgPGRjOnRpdGxlPjwvZGM6dGl0bGU+CiAgICAgIDwvY2M6V29yaz4KICAgIDwvcmRmOlJERj4KICA8L21ldGFkYXRhPgogIDxkZWZzCiAgICAgaWQ9ImRlZnMzMDQ1IiAvPgogIDxyZWN0CiAgICAgc3R5bGU9ImZpbGw6IzAwMDAwMDtzdHJva2U6bm9uZSIKICAgICBpZD0icmVjdDMwNTEiCiAgICAgeT0iOC4wMDg0NzQzIgogICAgIHg9IjIuMTYxMDE3MiIKICAgICBoZWlnaHQ9IjYuOTkxNTI1NyIKICAgICB3aWR0aD0iMTEuMDU5MzIyIiAvPgogIDxwYXRoCiAgICAgc3R5bGU9ImZpbGw6bm9uZTtzdHJva2U6IzAwMDAwMDtzdHJva2Utd2lkdGg6MS44OTk5OTk5ODtzdHJva2UtbGluZWNhcDpidXR0O3N0cm9rZS1saW5lam9pbjptaXRlcjtzdHJva2UtbWl0ZXJsaW1pdDo0O3N0cm9rZS1kYXNoYXJyYXk6bm9uZTtzdHJva2Utb3BhY2l0eToxIgogICAgIGlkPSJwYXRoMzg0OCIKICAgICBkPSJtIDMuMDgyNjI4LDUuMDIxMTg2NCBjIDAsMCAtMC4xMjcxMTksLTQuMDY3Nzk2NTIgNC40NDkxNTIsLTQuMDY3Nzk2NTIgNC41NzYyNjgsMCA0LjcwMzM4NiwzLjk0MDY3NzgyIDQuNzAzMzg2LDMuOTQwNjc3ODIgbCAwLjA2MzU2LDUuNTkzMjE5MyB2IDAiIC8+Cjwvc3ZnPgo=');
  background-repeat: no-repeat;
  background-position: center center;
  background-size: 14px 14px;
  opacity: 0.3;
  height: 44px;
  width: 44px;
  position: absolute;
  bottom: 0;
  right: 0;
  cursor: pointer; }
  div.jsxc_transfer:hover {
    opacity: 1.0; }
  div.jsxc_transfer.jsxc_disabled {
    background-image: url('data:image/svg+xml;base64,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');
    cursor: default; }
    div.jsxc_transfer.jsxc_disabled:hover {
      opacity: 0.3; }
  div.jsxc_transfer.jsxc_fin {
    opacity: 1.0;
    background-image: url('data:image/svg+xml;base64,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'); }
  div.jsxc_transfer.jsxc_enc {
    opacity: 1.0;
    background-image: url('data:image/svg+xml;base64,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'); }
    div.jsxc_transfer.jsxc_enc.jsxc_trust {
      background-image: url('data:image/svg+xml;base64,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'); }

.jsxc_windowItem.jsxc_groupchat.jsxc_normal .jsxc_bar .jsxc_avatar, li[data-type="groupchat"] .jsxc_avatar {
  text-indent: 999px;
  background-image: url('data:image/svg+xml;base64, ');
  background-size: 70% 70% !important;
  background-repeat: no-repeat; }

.jsxc_windowItem.jsxc_groupchat.jsxc_normal .jsxc_fade {
  padding-top: 44px; }

.jsxc_windowItem.jsxc_groupchat.jsxc_normal .jsxc_fingerprints, .jsxc_windowItem.jsxc_groupchat.jsxc_normal .jsxc_verification, .jsxc_windowItem.jsxc_groupchat.jsxc_normal .jsxc_transfer, .jsxc_windowItem.jsxc_groupchat.jsxc_normal .jsxc_video, .jsxc_windowItem.jsxc_groupchat.jsxc_normal .jsxc_sendFile {
  display: none; }

.jsxc_windowItem.jsxc_groupchat.jsxc_normal .jsxc_members {
  background-image: url('data:image/svg+xml;base64, ');
  background-size: 15px 15px;
  background-repeat: no-repeat;
  background-position: center; }
  .jsxc_windowItem.jsxc_groupchat.jsxc_normal .jsxc_members:hover {
    opacity: 1.0; }

.jsxc_windowItem.jsxc_groupchat.jsxc_normal .jsxc_chatmessage.jsxc_in {
  margin-left: 50px; }
  .jsxc_windowItem.jsxc_groupchat.jsxc_normal .jsxc_chatmessage.jsxc_in .jsxc_avatar {
    display: block;
    position: absolute;
    bottom: 0px;
    left: -50px;
    background-color: #777; }
    .jsxc_windowItem.jsxc_groupchat.jsxc_normal .jsxc_chatmessage.jsxc_in .jsxc_avatar:before {
      display: none; }

.jsxc_windowItem .jsxc_memberlist {
  height: 44px;
  width: 100%;
  background-color: #1d2d44;
  overflow: hidden;
  position: absolute;
  top: 0px;
  -webkit-transition: height 400ms;
          transition: height 400ms;
  z-index: 100; }
  .jsxc_windowItem .jsxc_memberlist ul {
    white-space: nowrap;
    position: absolute;
    background-color: #1d2d44;
    color: #bbb;
    overflow: hidden;
    -webkit-transition: left 400ms;
            transition: left 400ms;
    padding: 0px;
    padding-left: 6px;
    padding-right: 6px;
    padding-top: 3px; }
    .jsxc_windowItem .jsxc_memberlist ul > li {
      display: inline-block;
      white-space: normal; }
      .jsxc_windowItem .jsxc_memberlist ul > li:last-child {
        margin-right: 2px; }
      .jsxc_windowItem .jsxc_memberlist ul > li .jsxc_name {
        display: none; }
      .jsxc_windowItem .jsxc_memberlist ul > li .jsxc_avatar {
        margin-left: 2px;
        margin-right: 0px; }
  .jsxc_windowItem .jsxc_memberlist.jsxc_expand ul {
    white-space: normal; }
    .jsxc_windowItem .jsxc_memberlist.jsxc_expand ul > li {
      display: block;
      width: 100%;
      height: 40px;
      line-height: 40px; }
      .jsxc_windowItem .jsxc_memberlist.jsxc_expand ul > li .jsxc_name {
        display: block;
        cursor: default; }
        .jsxc_windowItem .jsxc_memberlist.jsxc_expand ul > li .jsxc_name:hover {
          color: inherit; }
      .jsxc_windowItem .jsxc_memberlist.jsxc_expand ul > li .jsxc_avatar {
        margin-right: 4px; }

li[data-type="groupchat"] .jsxc_video {
  display: none; }

.jsxc_right {
  text-align: right; }

.jsxc_center {
  text-align: center; }

.jsxc_sep {
  border-top: 1px solid #000; }

.jsxc_name {
  overflow: hidden;
  cursor: pointer;
  text-overflow: ellipsis;
  white-space: nowrap; }

.jsxc_maxWidth {
  max-width: 500px; }

#jsxc_dialog {
  padding: 20px;
  min-width: 320px;
  max-width: 100%;
  display: inline-block;
  text-align: left;
  position: relative;
  background: #FFF;
  width: auto;
  border-radius: 5px; }
  #jsxc_dialog * {
    box-sizing: border-box; }
  #jsxc_dialog ul {
    list-style: none;
    margin: 0;
    padding: 0; }
  #jsxc_dialog li {
    margin: 0;
    padding: 0; }
  #jsxc_dialog p {
    margin-bottom: 1em; }
    #jsxc_dialog p input {
      margin-bottom: 5px;
      width: 60%;
      outline: none; }
    #jsxc_dialog p input[type="submit"] {
      width: auto; }
  #jsxc_dialog hr {
    border: 0;
    border-top: 1px solid #eee;
    margin-top: 20px;
    margin-bottom: 20px; }
  #jsxc_dialog h3 {
    font-size: 120%;
    font-weight: bold;
    margin-bottom: 10px;
    margin-top: 20px; }
  #jsxc_dialog .jsxc_right {
    margin-top: 20px; }
  #jsxc_dialog form {
    /*&.col-sm-6:nth-child(odd) {
           clear: left;
        }*/ }
    #jsxc_dialog form fieldset {
      margin-bottom: 30px;
      padding: 0px 30px;
      border: 1px solid #d9d9d9; }
      #jsxc_dialog form fieldset h3 {
        font-size: 15px;
        color: #000;
        background-color: #f2f2f2;
        padding: 10px;
        margin: 0 -30px 10px -30px; }
  #jsxc_dialog legend {
    border: 0;
    font-size: 20px; }
  #jsxc_dialog input {
    outline: none; }
    #jsxc_dialog input:invalid {
      border: 1px solid #f00; }
  #jsxc_dialog .btn-group button {
    margin-right: 0; }
  #jsxc_dialog input[readonly] {
    background-color: #e6e6e6; }
  #jsxc_dialog .jsxc_inputinfo {
    padding-left: 30%;
    font-style: italic;
    margin-top: -1em; }
  #jsxc_dialog .jsxc_waiting:before {
    content: " ";
    width: 1em;
    height: 1em;
    display: inline-block;
    background-size: 100%;
    margin: 0 3px 0 0;
    background-image: url('data:image/gif;base64,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'); }
  #jsxc_dialog .jsxc_libraries, #jsxc_dialog .jsxc_credits {
    max-width: 300px; }

.jsxc_avatar {
  width: 36px;
  height: 36px;
  line-height: 36px;
  margin: 0px 5px;
  background-color: #999999;
  border-radius: 50%;
  float: left;
  text-align: center;
  font-weight: bold;
  font-size: 30px;
  color: #b3b3b3;
  position: relative;
  font-family: Arial, sans-serif;
  background-size: cover;
  background-position: center center; }
  .jsxc_avatar img {
    display: block;
    width: 25px;
    height: 25px;
    position: absolute;
    top: 0;
    left: 0; }
  .jsxc_avatar:before {
    position: absolute;
    top: -2px;
    left: -6px;
    border: 2px solid whitesmoke; }

ul.jsxc_vCard {
  min-width: 400px; }
  ul.jsxc_vCard ul {
    margin-left: 20px; }
  ul.jsxc_vCard li {
    cursor: default !important; }

/** Spot which is attached to xmpp: uris */
.jsxc_spot {
  display: inline-block;
  width: 12px;
  height: 12px;
  border-radius: 50%;
  text-indent: -99999em;
  margin-top: 3px;
  margin-right: 5px;
  line-height: 100%;
  cursor: pointer;
  border: 1px solid #000;
  background-color: #fff; }
  .jsxc_spot:before {
    position: absolute; }
  .jsxc_spot.jsxc_online, .jsxc_spot.jsxc_chat, .jsxc_spot.jsxc_away, .jsxc_spot.jsxc_xa, .jsxc_spot.jsxc_dnd, .jsxc_spot.jsxc_offline {
    border: 0; }

.jsxc_unread {
  display: none; }

.jsxc_unreadMsg .jsxc_name {
  font-style: italic; }

.jsxc_unreadMsg .jsxc_unread {
  display: block;
  background-color: #ffa500;
  border-radius: 11px;
  color: #000;
  font-size: 80%;
  padding: 2px;
  line-height: 15px;
  float: right;
  margin-right: 3px;
  margin-top: 4px; }

/** TODO: check if required */
.jsxc_list .jsxc_inner {
  box-sizing: border-box;
  max-height: 0;
  -webkit-transition: max-height 0.5s;
          transition: max-height 0.5s;
  overflow: hidden;
  visibility: hidden;
  position: absolute;
  bottom: 100%;
  left: 0; }

.jsxc_list.jsxc_opened .jsxc_inner {
  max-height: 1000px;
  visibility: visible;
  display: block; }

#cboxWrapper {
  outline: none; }

.jsxc_loading {
  margin: 0 auto;
  width: 32px;
  height: 32px;
  border: 0;
  background-size: 32px 32px !important;
  background: url('data:image/gif;base64,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'); }

/* @TODO: check */
#jsxc_loginForm input[type="submit"] {
  height: 34px;
  display: inline-block;
  padding: 6px 12px;
  margin-bottom: 0;
  font-size: 14px;
  font-weight: normal;
  line-height: 1.428571429;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  cursor: pointer;
  border: 1px solid transparent;
  border-radius: 4px;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  color: #fff;
  background-color: #5cb85c;
  border-color: #4cae4c; }

.jsxc_oneway .jsxc_avatar {
  -webkit-filter: grayscale(100%);
          filter: grayscale(100%); }

img.jsxc_vCard {
  float: right;
  max-width: 200px;
  max-height: 200px;
  border: 5px solid #fff;
  border-radius: 2px; }

.jsxc_alert {
  padding: 15px;
  margin-bottom: 20px;
  border: 1px solid transparent;
  border-radius: 4px; }
  .jsxc_alert.jsxc_alert-warning {
    color: #8a6d3b;
    background-color: #fcf8e3;
    border-color: #faebcc; }

.jsxc_btn {
  width: auto;
  min-width: 25px;
  display: inline-block;
  padding: 6px 12px;
  margin: 0px 2px;
  font-size: 14px;
  font-weight: 400;
  line-height: 1.42857143;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  cursor: pointer;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  background-image: none;
  border: 1px solid transparent;
  border-radius: 4px; }
  .jsxc_btn.jsxc_btn-default {
    border-color: #ccc;
    color: #555;
    background-color: rgba(240, 240, 240, 0.9); }
  .jsxc_btn.jsxc_btn-primary {
    color: #fff;
    background-color: #337ab7;
    border-color: #2e6da4; }
  .jsxc_btn[disabled], .jsxc_btn[disabled]:hover {
    opacity: 0.65;
    cursor: not-allowed;
    color: #fff;
    background-color: #337ab7;
    border-color: #2e6da4; }

.jsxc_menu {
  display: none;
  position: absolute;
  background-color: #FFF;
  color: #333;
  border-radius: 3px 3px 3px 3px;
  z-index: 110;
  margin: 8px 2px 5px 10px;
  right: 0px;
  -webkit-filter: drop-shadow(0px 0px 5px rgba(150, 150, 150, 0.75));
          filter: drop-shadow(0px 0px 5px rgba(150, 150, 150, 0.75));
  padding: 4px 12px;
  padding-left: 5px; }
  .jsxc_menu:after {
    bottom: 100%;
    right: 6px;
    border: solid transparent;
    content: " ";
    height: 0;
    width: 0;
    position: absolute;
    pointer-events: none;
    border-color: rgba(238, 238, 238, 0);
    border-bottom-color: #fff;
    border-width: 10px; }
  .jsxc_menu.jsxc_open {
    display: block; }
  .jsxc_menu ul {
    list-style: none;
    margin: 0;
    padding: 0; }
  .jsxc_menu li {
    border: 0;
    cursor: auto; }
  .jsxc_menu a {
    color: #000;
    opacity: 0.5;
    white-space: nowrap; }
    .jsxc_menu a:hover {
      text-decoration: none;
      opacity: 1.0; }
    .jsxc_menu a.jsxc_disabled {
      text-decoration: line-through;
      opacity: 0.5; }
      .jsxc_menu a.jsxc_disabled:hover {
        text-decoration: line-through;
        opacity: 0.5; }
      .jsxc_menu a.jsxc_disabled span {
        cursor: default; }
  .jsxc_menu .jsxc_icon {
    width: 16px;
    height: 16px;
    margin-right: 8px;
    display: inline-block;
    background-repeat: no-repeat;
    background-size: contain;
    background-position: center;
    vertical-align: sub; }

.jsxc_editicon {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+CjxzdmcgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGhlaWdodD0iMTYiIHdpZHRoPSIxNiIgdmVyc2lvbj0iMS4xIiB4bWxuczpjYz0iaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbnMjIiB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iPgogPGcgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMCAtMTAzNi40KSI+CiAgPHBhdGggZD0ibTEyLjU5NCAxLjM0MzhjLTAuNTMyLTAuMDMxMy0xLjA5NCAwLjE1NjItMS41OTQgMC42NTYybDMgM2MxLjUtMS41IDAuMTg4LTMuNTYyNS0xLjQwNi0zLjY1NjJ6bS0yLjU5NCAxLjY1NjJsLTcgNy0yIDUgNS0yIDctNy0zLTN6bS02LjUgNy41bDIgMi0yLjUgMS41LTEtMSAxLjUtMi41eiIgdHJhbnNmb3JtPSJ0cmFuc2xhdGUoMCAxMDM2LjQpIi8+CiA8L2c+Cjwvc3ZnPgo='); }

.jsxc_deleteicon {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+CjxzdmcgeG1sbnM6cmRmPSJodHRwOi8vd3d3LnczLm9yZy8xOTk5LzAyLzIyLXJkZi1zeW50YXgtbnMjIiB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGhlaWdodD0iMTYiIHdpZHRoPSIxNiIgdmVyc2lvbj0iMS4xIiB4bWxuczpjYz0iaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbnMjIiB4bWxuczpkYz0iaHR0cDovL3B1cmwub3JnL2RjL2VsZW1lbnRzLzEuMS8iPgogPHBhdGggZD0ibTYuNSAxLTAuNSAxaC0zYy0wLjU1NCAwLTEgMC40NDYtMSAxdjFoMTJ2LTFjMC0wLjU1NC0wLjQ0Ni0xLTEtMWgtM2wtMC41LTF6bS0zLjUgNCAwLjg3NSA5YzAuMDYxIDAuNTQ5IDAuNTcyOSAxIDEuMTI1IDFoNmMwLjU1MjMyIDAgMS4wNjQtMC40NTEwMiAxLjEyNS0xbDAuODc1LTl6IiBmaWxsLXJ1bGU9ImV2ZW5vZGQiLz4KPC9zdmc+Cg=='); }

.jsxc_chaticon {
  background-image: url('data:image/svg+xml;base64,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'); }

.jsxc_videoicon {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+CjxzdmcKICAgeG1sbnM6ZGM9Imh0dHA6Ly9wdXJsLm9yZy9kYy9lbGVtZW50cy8xLjEvIgogICB4bWxuczpjYz0iaHR0cDovL2NyZWF0aXZlY29tbW9ucy5vcmcvbnMjIgogICB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiCiAgIHhtbG5zOnN2Zz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciCiAgIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIKICAgdmlld0JveD0iMCAwIDIwIDIwIgogICBoZWlnaHQ9IjIwIgogICB3aWR0aD0iMjAiCiAgIGlkPSJzdmcyIgogICB2ZXJzaW9uPSIxLjEiPgogIDxtZXRhZGF0YQogICAgIGlkPSJtZXRhZGF0YTEwIj4KICAgIDxyZGY6UkRGPgogICAgICA8Y2M6V29yawogICAgICAgICByZGY6YWJvdXQ9IiI+CiAgICAgICAgPGRjOmZvcm1hdD5pbWFnZS9zdmcreG1sPC9kYzpmb3JtYXQ+CiAgICAgICAgPGRjOnR5cGUKICAgICAgICAgICByZGY6cmVzb3VyY2U9Imh0dHA6Ly9wdXJsLm9yZy9kYy9kY21pdHlwZS9TdGlsbEltYWdlIiAvPgogICAgICAgIDxkYzp0aXRsZT48L2RjOnRpdGxlPgogICAgICA8L2NjOldvcms+CiAgICA8L3JkZjpSREY+CiAgPC9tZXRhZGF0YT4KICA8ZGVmcwogICAgIGlkPSJkZWZzOCIgLz4KICA8ZwogICAgIHN0eWxlPSJmaWxsOiMwMDAwMDAiCiAgICAgdHJhbnNmb3JtPSJtYXRyaXgoMC4wMzc4ODU5NCwwLDAsMC4wMzc4ODU5NCwtMC40MTM0MDc5MywtMi42MzEwNzE2KSIKICAgICBpZD0ibGF5ZXIxIj4KICAgIDxwYXRoCiAgICAgICBkPSJNIDM2MS42NTE0OCwzMTMuNTE3NjggNTM4LjgxMjIyLDE4MS43MzI1MiBWIDQ4My45NjI1MSBMIDM1OC45NzMzOCwzNTAuMTg1MTcgWiBNIDEwLjkxMTkyMiwxODIuNDA2MzQgSCAzODkuMjg0NiBWIDQ4NS4wNjIxNiBIIDEwLjkxMTkyMiBaIgogICAgICAgc3R5bGU9ImZpbGw6IzAwMDAwMDtzdHJva2U6bm9uZSIKICAgICAgIGlkPSJwYXRoMzkwNiIgLz4KICA8L2c+Cjwvc3ZnPgo='); }

.jsxc_infoicon {
  background-image: url('data:image/svg+xml;base64,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'); }

.jsxc_settingsicon {
  background-image: url('data:image/svg+xml;base64, '); }

.jsxc_helpicon {
  background-image: url('data:image/svg+xml;base64,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'); }

.jsxc_contacticon {
  background-image: url('data:image/svg+xml;base64,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'); }

.jsxc_groupcontacticon {
  background-image: url('data:image/svg+xml;base64, '); }

.jsxc_bookmarkicon {
  background-image: url('data:image/svg+xml;base64,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'); }

.jsxc_more {
  float: right;
  width: 44px;
  height: 100%;
  cursor: pointer;
  background-image: url('data:image/svg+xml;base64,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');
  background-repeat: no-repeat;
  background-position: center;
  opacity: 0.4; }
  .jsxc_more:hover {
    opacity: 1.0; }
  @media (min-width: 768px) {
    .jsxc_more {
      width: 25px; } }

.jsxc_remotevideo, .jsxc_noRemoteVideo {
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0;
  left: 0;
  z-index: 9000;
  background-color: #999999; }

#jsxc_webrtc {
  position: fixed;
  top: 0;
  bottom: 0;
  right: 0;
  left: 0;
  z-index: 9999;
  background-color: black; }
  #jsxc_webrtc .jsxc_status {
    z-index: 9999;
    border-radius: 20px;
    display: none;
    position: absolute;
    top: 30px;
    left: 50%;
    background-color: rgba(0, 0, 0, 0.5);
    color: #fff;
    padding: 15px;
    font-weight: bold;
    text-align: center; }
  #jsxc_webrtc .slimScrollDiv {
    opacity: 1 !important; }
  #jsxc_webrtc li .jsxc_name {
    cursor: auto; }
    #jsxc_webrtc li .jsxc_name:hover {
      color: #bbb; }

.jsxc_videoContainer {
  position: absolute;
  top: 0;
  left: 0;
  right: 0px;
  bottom: 0px;
  background-color: #999999; }
  .jsxc_videoContainer video {
    display: none; }
  .jsxc_videoContainer .jsxc_noRemoteVideo {
    display: none; }
  @media (min-width: 768px) {
    .jsxc_videoContainer {
      right: 250px; }
      .jsxc_videoContainer .jsxc_controlbar {
        opacity: 0; }
      .jsxc_videoContainer:hover .jsxc_controlbar {
        opacity: 1.0; } }

.jsxc_noRemoteVideo p {
  position: absolute;
  bottom: 0;
  left: 0;
  text-align: center;
  color: #fff;
  width: 100%;
  z-index: 100; }

.jsxc_noRemoteVideo > div {
  width: 200px;
  height: 200px;
  overflow: hidden;
  position: absolute;
  top: 50%;
  margin-top: -100px;
  left: 50%;
  margin-left: -100px; }
  .jsxc_noRemoteVideo > div > div {
    background-color: #4d4d4d; }
    .jsxc_noRemoteVideo > div > div:first-child {
      width: 50%;
      height: 50%;
      border-radius: 50%;
      position: absolute;
      left: 50%;
      margin-left: -25%;
      top: 10%; }
    .jsxc_noRemoteVideo > div > div:last-child {
      position: absolute;
      bottom: -50%;
      width: 100%;
      height: 100%;
      border-radius: 50%; }

.jsxc_localvideo {
  width: 160px;
  height: 120px;
  position: absolute;
  right: 10px;
  bottom: 10px;
  z-index: 9990;
  background-color: #000;
  cursor: pointer; }

div:full-screen {
  width: 100%;
  height: 100%;
  background-color: #000; }
  div:full-screen.jsxc_localvideo {
    border: 1px solid #fff; }

div:-webkit-full-screen {
  width: 100%;
  height: 100%;
  background-color: #000; }

div:-moz-full-screen {
  width: 100%;
  height: 100%;
  background-color: #000; }

div:-ms-fullscreen {
  width: 100%;
  height: 100%;
  background-color: #000; }

div:fullscreen {
  width: 100%;
  height: 100%;
  background-color: #000; }
  div:-webkit-full-screen.jsxc_localvideo {
    border: 1px solid #fff; }
  div:-moz-full-screen.jsxc_localvideo {
    border: 1px solid #fff; }
  div:-ms-fullscreen.jsxc_localvideo {
    border: 1px solid #fff; }
  div:fullscreen.jsxc_localvideo {
    border: 1px solid #fff; }

div.jsxc_video {
  background-image: url('data:image/svg+xml;base64,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');
  background-repeat: no-repeat;
  background-position: center center;
  background-size: 15px 15px;
  opacity: 0.4; }
  div.jsxc_video.jsxc_disabled {
    background-image: url('data:image/svg+xml;base64, '); }
  div.jsxc_video:not(.jsxc_disabled):hover {
    opacity: 1.0; }

.jsxc_controlbar {
  position: absolute;
  top: 50px;
  left: 0;
  right: 0px;
  text-align: center;
  z-index: 9090;
  -webkit-transition: 1s opacity;
          transition: 1s opacity;
  opacity: 0; }
  @media (min-width: 768px) {
    .jsxc_controlbar {
      bottom: 5%;
      top: initial; } }
  .jsxc_controlbar.jsxc_visible {
    opacity: 1.0; }
  .jsxc_controlbar > div {
    background-color: rgba(0, 0, 0, 0.5);
    height: 44px;
    border-radius: 22px;
    padding: 0px 5px;
    display: inline-block; }
  .jsxc_controlbar .jsxc_videoControl {
    height: 44px;
    width: 44px;
    margin: 0 5px;
    background-position: center;
    background-repeat: no-repeat;
    background-size: 90%;
    cursor: pointer;
    display: inline-block;
    opacity: 0.8; }
    .jsxc_controlbar .jsxc_videoControl:hover {
      opacity: 1.0; }
  .jsxc_controlbar .jsxc_hangUp {
    background-image: url('data:image/svg+xml;base64,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'); }
  .jsxc_controlbar .jsxc_fullscreen {
    background-image: url('data:image/svg+xml;base64,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'); }
  .jsxc_controlbar .jsxc_showchat {
    float: right; }

.jsxc_multi > div {
  display: none; }

.jsxc_snapshotbar {
  width: 100%;
  display: none; }
  .jsxc_snapshotbar img {
    height: 50px; }

.jsxc_buttongroup {
  display: inline; }
  .jsxc_buttongroup button:first-child {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
    margin-right: 0; }
  .jsxc_buttongroup button:last-child {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    margin-left: 0; }

.jsxc_chatarea {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  width: 250px;
  background-color: whitesmoke;
  display: none; }
  @media (min-width: 768px) {
    .jsxc_chatarea {
      display: block; } }
  .jsxc_chatarea .jsxc_settings {
    display: none !important; }
  .jsxc_chatarea .jsxc_close {
    display: none !important; }
  .jsxc_chatarea .jsxc_video {
    display: none !important; }
  .jsxc_chatarea .jsxc_window {
    bottom: 0;
    box-shadow: none; }
  .jsxc_chatarea > ul {
    width: 100%;
    height: 100%;
    list-style: none;
    padding: 0; }

.bubblingG {
  text-align: center;
  width: 129px;
  height: 80px;
  position: absolute;
  top: 40%;
  left: 50%;
  margin-left: -64px; }
  .bubblingG span {
    display: inline-block;
    vertical-align: middle;
    width: 16px;
    height: 16px;
    margin: 40px auto;
    background: #000;
    border-radius: 81px;
    -webkit-animation: bubblingG 1.3s infinite alternate;
            animation: bubblingG 1.3s infinite alternate; }

#bubblingG_1 {
  -webkit-animation-delay: 0s;
          animation-delay: 0s; }

#bubblingG_2 {
  -webkit-animation-delay: 0.39s;
          animation-delay: 0.39s; }

#bubblingG_3 {
  -webkit-animation-delay: 0.78s;
          animation-delay: 0.78s; }

@-webkit-keyframes bubblingG {
  0% {
    width: 16px;
    height: 16px;
    background-color: #000;
    -webkit-transform: translateY(0);
            transform: translateY(0); }
  100% {
    width: 39px;
    height: 39px;
    background-color: #fff;
    -webkit-transform: translateY(-34px);
            transform: translateY(-34px); } }

@keyframes bubblingG {
  0% {
    width: 16px;
    height: 16px;
    background-color: #000;
    -webkit-transform: translateY(0);
            transform: translateY(0); }
  100% {
    width: 39px;
    height: 39px;
    background-color: #fff;
    -webkit-transform: translateY(-34px);
            transform: translateY(-34px); } }

.jsxc_fullscreen.jsxc_localvideo {
  border: 1px solid #fff; }

.jsxc_videoSuitable .jsxc_name {
  font-style: italic; }
